@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:25-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:08-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -42,7 +42,7 @@ asmmac_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd27;
   machine_word Wrd22;
   machine_word Wrd6;
@@ -419,7 +419,7 @@ asmmac_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd18;
   machine_word Wrd15;
   machine_word Wrd35;
@@ -723,7 +723,7 @@ asmmac_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd44;
   machine_word Wrd40;
   machine_word Wrd37;
@@ -1509,11 +1509,11 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-asmmac_so_feeff5c36028d06f (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+asmmac_so_6219e73c256c8a38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd6;
   machine_word Wrd10;
   machine_word Wrd9;
@@ -1660,7 +1660,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_asmmac_so_feeff5c36028d06f [3] =
+static const struct liarc_code_S arr_decl_asmmac_so_6219e73c256c8a38 [3] =
   {
     { "asmmac_so_code_1", 13, asmmac_so_code_1 },
     { "asmmac_so_code_2", 10, asmmac_so_code_2 },
@@ -1668,19 +1668,19 @@ static const struct liarc_code_S arr_decl_asmmac_so_feeff5c36028d06f [3] =
   };
 
 int
-decl_asmmac_so_feeff5c36028d06f (void)
+decl_asmmac_so_6219e73c256c8a38 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_asmmac_so_feeff5c36028d06f);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_asmmac_so_6219e73c256c8a38);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("asmmac.so", 7, decl_asmmac_so_feeff5c36028d06f, asmmac_so_feeff5c36028d06f)
+DECLARE_COMPILED_CODE ("asmmac.so", 7, decl_asmmac_so_6219e73c256c8a38, asmmac_so_6219e73c256c8a38)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_asmmac_so_data_feeff5c36028d06f [1131] =
+static const unsigned char prog_asmmac_so_data_6219e73c256c8a38 [1131] =
   "\x58\x0a\xef\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x0d\x0d\xb9"
   "\xc1\xba\x08\x0d\x0d\x0d\xbb\x0d\xb3\x08\x8a\x08\x8a\xc1\xbb\x28"
   "\x0d\x28\x0d\x28\x0d\xbc\x28\x0d\xbd\x28\x0d\x28\x0d\xbe\x23\x22"
@@ -1697,9 +1697,9 @@ static const unsigned char prog_asmmac_so_data_feeff5c36028d06f [1131] =
   "\x88\xb5\xb6\x2a\x0d\xc2\x02\x02\x0d\xc3\xb4\x1b\x2a\xb7\x2a\x28"
   "\x0d\x26\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x21\x17\x02\x59\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53"
-  "\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72"
-  "\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74"
-  "\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f"
+  "\x6f\x66\x74\x77\x61\x72\x65\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65"
+  "\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x32\x2f\x6d"
+  "\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x32\x2f"
   "\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61\x63"
   "\x6b\x2f\x61\x73\x6d\x6d\x61\x63\x2e\x69\x6e\x66\x15\x23\x5b\x70"
   "\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74"
@@ -1754,19 +1754,19 @@ static const unsigned char prog_asmmac_so_data_feeff5c36028d06f [1131] =
   "\x06\x81\x85\x02\x01\x04\x81\x83\x02\x0f\x21";
 
 SCHEME_OBJECT *
-asmmac_so_data_feeff5c36028d06f (entry_count_t dispatch_base)
+asmmac_so_data_6219e73c256c8a38 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_asmmac_so_data_feeff5c36028d06f [0]))), (sizeof (prog_asmmac_so_data_feeff5c36028d06f)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_asmmac_so_data_6219e73c256c8a38 [0]))), (sizeof (prog_asmmac_so_data_6219e73c256c8a38)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_11]));
 }
 
-DECLARE_COMPILED_DATA_NS ("asmmac.so", asmmac_so_data_feeff5c36028d06f)
+DECLARE_COMPILED_DATA_NS ("asmmac.so", asmmac_so_data_6219e73c256c8a38)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("asmmac.so", "12dc089e8dda5132")
+DECLARE_DYNAMIC_INITIALIZATION ("asmmac.so", "a3b042554c11050e")
