@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:25-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:08-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -17,7 +17,7 @@ asutl_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd9;
   machine_word Wrd8;
   machine_word Wrd7;
@@ -89,7 +89,7 @@ asutl_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd10;
   machine_word Wrd14;
   machine_word Wrd12;
@@ -160,7 +160,7 @@ asutl_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd10;
   machine_word Wrd14;
   machine_word Wrd12;
@@ -231,7 +231,7 @@ asutl_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd10;
   machine_word Wrd14;
   machine_word Wrd12;
@@ -301,7 +301,7 @@ asutl_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   INVOKE_INTERFACE_DECLS
 
   Rdl = (OBJECT_ADDRESS (Rvl));
@@ -346,7 +346,7 @@ asutl_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   INVOKE_INTERFACE_DECLS
 
   Rdl = (OBJECT_ADDRESS (Rvl));
@@ -391,7 +391,7 @@ asutl_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd13;
   machine_word Wrd11;
   machine_word Wrd9;
@@ -494,11 +494,11 @@ INVOKE_INTERFACE_TARGET_0
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-asutl_so_f52196d51fff5136 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+asutl_so_87c46a7985459430 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd52;
   machine_word Wrd56;
   machine_word Wrd54;
@@ -919,7 +919,7 @@ INVOKE_INTERFACE_TARGET_0
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_asutl_so_f52196d51fff5136 [7] =
+static const struct liarc_code_S arr_decl_asutl_so_87c46a7985459430 [7] =
   {
     { "asutl_so_code_1", 1, asutl_so_code_1 },
     { "asutl_so_code_2", 1, asutl_so_code_2 },
@@ -931,19 +931,19 @@ static const struct liarc_code_S arr_decl_asutl_so_f52196d51fff5136 [7] =
   };
 
 int
-decl_asutl_so_f52196d51fff5136 (void)
+decl_asutl_so_87c46a7985459430 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_asutl_so_f52196d51fff5136);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_asutl_so_87c46a7985459430);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("asutl.so", 16, decl_asutl_so_f52196d51fff5136, asutl_so_f52196d51fff5136)
+DECLARE_COMPILED_CODE ("asutl.so", 16, decl_asutl_so_87c46a7985459430, asutl_so_87c46a7985459430)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_asutl_so_data_f52196d51fff5136 [697] =
+static const unsigned char prog_asutl_so_data_87c46a7985459430 [697] =
   "\x3a\x0a\xa0\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x07\x22\x29\x21"
   "\x9d\x2b\xb9\x1d\xb0\x82\x88\x22\x29\x21\x9c\x2b\xba\x1d\xb0\x83"
   "\x88\x22\x29\x21\x9c\x2b\xbb\x1d\xb0\x84\x88\x22\x29\x21\x9c\x2b"
@@ -955,9 +955,9 @@ static const unsigned char prog_asutl_so_data_f52196d51fff5136 [697] =
   "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x21\x17\x02\x58\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
-  "\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f"
-  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69"
-  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31"
+  "\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x6d\x69\x74\x2d\x73\x63\x68"
+  "\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x32\x2f"
+  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x32"
   "\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61"
   "\x63\x6b\x2f\x61\x73\x75\x74\x6c\x2e\x69\x6e\x66\x15\x23\x5b\x70"
   "\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74"
@@ -990,19 +990,19 @@ static const unsigned char prog_asutl_so_data_f52196d51fff5136 [697] =
   "\x89\x02\x01\x04\x81\x83\x02\x21\x3a";
 
 SCHEME_OBJECT *
-asutl_so_data_f52196d51fff5136 (entry_count_t dispatch_base)
+asutl_so_data_87c46a7985459430 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_asutl_so_data_f52196d51fff5136 [0]))), (sizeof (prog_asutl_so_data_f52196d51fff5136)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_asutl_so_data_87c46a7985459430 [0]))), (sizeof (prog_asutl_so_data_87c46a7985459430)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_24]));
 }
 
-DECLARE_COMPILED_DATA_NS ("asutl.so", asutl_so_data_f52196d51fff5136)
+DECLARE_COMPILED_DATA_NS ("asutl.so", asutl_so_data_87c46a7985459430)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("asutl.so", "7ced3580e668696b")
+DECLARE_DYNAMIC_INITIALIZATION ("asutl.so", "56ea711c41ec5b88")
