@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:26-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:08-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -18,7 +18,7 @@ checks_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd5;
   INVOKE_INTERFACE_DECLS
 
@@ -67,7 +67,7 @@ checks_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd5;
   INVOKE_INTERFACE_DECLS
 
@@ -121,7 +121,7 @@ checks_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd14;
   machine_word Wrd8;
   machine_word Wrd13;
@@ -218,7 +218,7 @@ checks_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd14;
   machine_word Wrd8;
   machine_word Wrd13;
@@ -314,7 +314,7 @@ checks_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd9;
   machine_word Wrd14;
   machine_word Wrd13;
@@ -532,7 +532,7 @@ checks_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd23;
   machine_word Wrd26;
   machine_word Wrd31;
@@ -1960,11 +1960,11 @@ INVOKE_INTERFACE_TARGET_0
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-checks_so_359e5705e22ca20d (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+checks_so_a39c431bd07d5cc4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd8;
   machine_word Wrd6;
   machine_word Wrd5;
@@ -2043,7 +2043,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_checks_so_359e5705e22ca20d [6] =
+static const struct liarc_code_S arr_decl_checks_so_a39c431bd07d5cc4 [6] =
   {
     { "checks_so_code_1", 1, checks_so_code_1 },
     { "checks_so_code_2", 1, checks_so_code_2 },
@@ -2054,19 +2054,19 @@ static const struct liarc_code_S arr_decl_checks_so_359e5705e22ca20d [6] =
   };
 
 int
-decl_checks_so_359e5705e22ca20d (void)
+decl_checks_so_a39c431bd07d5cc4 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_checks_so_359e5705e22ca20d);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_checks_so_a39c431bd07d5cc4);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("checks.so", 3, decl_checks_so_359e5705e22ca20d, checks_so_359e5705e22ca20d)
+DECLARE_COMPILED_CODE ("checks.so", 3, decl_checks_so_a39c431bd07d5cc4, checks_so_a39c431bd07d5cc4)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_checks_so_data_359e5705e22ca20d [2162] =
+static const unsigned char prog_checks_so_data_a39c431bd07d5cc4 [2162] =
   "\xf2\x01\x0d\x84\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\xb9\x28"
   "\x0d\xba\x23\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x82\x88\x0d\xbc\x28"
   "\xb2\x23\x22\x29\x21\x17\x2b\xbd\x1d\xb0\x83\x88\x1d\x0c\x0d\xbe"
@@ -2092,10 +2092,10 @@ static const unsigned char prog_checks_so_data_359e5705e22ca20d [2162] =
   "\x29\x21\x17\x2b\xbe\x9d\xbc\x88\xb4\xb6\x2a\x1b\x2a\x1b\x2a\x1b"
   "\x2a\xb5\x2a\xb3\x2a\x9d\x0d\xb2\x0d\x0d\x1b\xb7\x9d\x28\x0d\x26"
   "\x22\x29\x22\x29\x22\x29\x21\x17\x02\x59\x2f\x55\x73\x65\x72\x73"
-  "\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63"
-  "\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c"
+  "\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x6d\x69"
+  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65"
+  "\x2d\x39\x2e\x32\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
+  "\x63\x2d\x39\x2e\x32\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c"
   "\x65\x72\x2f\x62\x61\x63\x6b\x2f\x63\x68\x65\x63\x6b\x73\x2e\x69"
   "\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f"
   "\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x17\x65\x6e\x74\x72\x79\x2d\x69"
@@ -2205,19 +2205,19 @@ static const unsigned char prog_checks_so_data_359e5705e22ca20d [2162] =
   "\x07\x11";
 
 SCHEME_OBJECT *
-checks_so_data_359e5705e22ca20d (entry_count_t dispatch_base)
+checks_so_data_a39c431bd07d5cc4 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_checks_so_data_359e5705e22ca20d [0]))), (sizeof (prog_checks_so_data_359e5705e22ca20d)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_checks_so_data_a39c431bd07d5cc4 [0]))), (sizeof (prog_checks_so_data_a39c431bd07d5cc4)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("checks.so", checks_so_data_359e5705e22ca20d)
+DECLARE_COMPILED_DATA_NS ("checks.so", checks_so_data_a39c431bd07d5cc4)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("checks.so", "04402556932e6b0a")
+DECLARE_DYNAMIC_INITIALIZATION ("checks.so", "583444fcd1c3d485")
