@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:29-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:10-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -32,7 +32,7 @@ contin_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd29;
   machine_word Wrd21;
   machine_word Wrd26;
@@ -223,7 +223,7 @@ contin_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd14;
   machine_word Wrd13;
   machine_word Wrd5;
@@ -324,7 +324,7 @@ contin_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd5;
   machine_word Wrd16;
   machine_word Wrd15;
@@ -444,7 +444,7 @@ contin_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd10;
   machine_word Wrd11;
   machine_word Wrd8;
@@ -542,7 +542,7 @@ contin_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd8;
   machine_word Wrd7;
   INVOKE_INTERFACE_DECLS
@@ -614,7 +614,7 @@ contin_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd11;
   machine_word Wrd8;
   machine_word Wrd7;
@@ -702,7 +702,7 @@ contin_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd17;
   machine_word Wrd15;
   machine_word Wrd11;
@@ -969,7 +969,7 @@ contin_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd8;
   machine_word Wrd7;
   INVOKE_INTERFACE_DECLS
@@ -1041,7 +1041,7 @@ contin_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd11;
   machine_word Wrd8;
   machine_word Wrd7;
@@ -1123,7 +1123,7 @@ contin_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd12;
   machine_word Wrd5;
   machine_word Wrd9;
@@ -1372,11 +1372,11 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-contin_so_aecea5170464e637 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+contin_so_3aa99623a3b4b4e6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd15;
   machine_word Wrd14;
   machine_word Wrd6;
@@ -2542,7 +2542,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_contin_so_aecea5170464e637 [10] =
+static const struct liarc_code_S arr_decl_contin_so_3aa99623a3b4b4e6 [10] =
   {
     { "contin_so_code_1", 7, contin_so_code_1 },
     { "contin_so_code_2", 3, contin_so_code_2 },
@@ -2557,19 +2557,19 @@ static const struct liarc_code_S arr_decl_contin_so_aecea5170464e637 [10] =
   };
 
 int
-decl_contin_so_aecea5170464e637 (void)
+decl_contin_so_3aa99623a3b4b4e6 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_contin_so_aecea5170464e637);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_contin_so_3aa99623a3b4b4e6);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("contin.so", 68, decl_contin_so_aecea5170464e637, contin_so_aecea5170464e637)
+DECLARE_COMPILED_CODE ("contin.so", 68, decl_contin_so_3aa99623a3b4b4e6, contin_so_3aa99623a3b4b4e6)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_contin_so_data_aecea5170464e637 [3231] =
+static const unsigned char prog_contin_so_data_3aa99623a3b4b4e6 [3231] =
   "\xd9\x01\x14\x87\x04\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc3\x02\x08"
   "\x0d\x0d\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x23\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xb9"
@@ -2604,9 +2604,9 @@ static const unsigned char prog_contin_so_data_aecea5170464e637 [3231] =
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x59\x2f\x55\x73"
   "\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65"
-  "\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
-  "\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
-  "\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65"
+  "\x61\x73\x65\x2d\x39\x2e\x32\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65"
+  "\x6d\x65\x2d\x63\x2d\x39\x2e\x32\x2f\x73\x72\x63\x2f\x63\x6f\x6d"
   "\x70\x69\x6c\x65\x72\x2f\x62\x61\x73\x65\x2f\x63\x6f\x6e\x74\x69"
   "\x6e\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61"
   "\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0c\x76\x65\x63\x74"
@@ -2774,19 +2774,19 @@ static const unsigned char prog_contin_so_data_aecea5170464e637 [3231] =
   "\x02\x02\x06\x81\x83\x02\x01\x04\x81\x83\x02\x89\x01\xd9\x01";
 
 SCHEME_OBJECT *
-contin_so_data_aecea5170464e637 (entry_count_t dispatch_base)
+contin_so_data_3aa99623a3b4b4e6 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_contin_so_data_aecea5170464e637 [0]))), (sizeof (prog_contin_so_data_aecea5170464e637)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_contin_so_data_3aa99623a3b4b4e6 [0]))), (sizeof (prog_contin_so_data_3aa99623a3b4b4e6)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_74]));
 }
 
-DECLARE_COMPILED_DATA_NS ("contin.so", contin_so_data_aecea5170464e637)
+DECLARE_COMPILED_DATA_NS ("contin.so", contin_so_data_3aa99623a3b4b4e6)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("contin.so", "419885123c99e6bd")
+DECLARE_DYNAMIC_INITIALIZATION ("contin.so", "e21d21feead69967")
