@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:33-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:13-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -16,7 +16,7 @@ scode_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   INVOKE_INTERFACE_DECLS
 
   Rdl = (OBJECT_ADDRESS (Rvl));
@@ -62,7 +62,7 @@ scode_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   INVOKE_INTERFACE_DECLS
 
   Rdl = (OBJECT_ADDRESS (Rvl));
@@ -110,7 +110,7 @@ scode_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd5;
   machine_word Wrd8;
   machine_word Wrd7;
@@ -181,7 +181,7 @@ scode_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd25;
   machine_word Wrd22;
   machine_word Wrd24;
@@ -302,7 +302,7 @@ scode_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd22;
   machine_word Wrd25;
   machine_word Wrd19;
@@ -482,7 +482,7 @@ scode_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd49;
   machine_word Wrd43;
   machine_word Wrd44;
@@ -695,7 +695,7 @@ scode_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd16;
   machine_word Wrd21;
   machine_word Wrd20;
@@ -844,7 +844,7 @@ scode_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   INVOKE_INTERFACE_DECLS
 
   Rdl = (OBJECT_ADDRESS (Rvl));
@@ -894,7 +894,7 @@ scode_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd10;
   machine_word Wrd9;
   machine_word Wrd8;
@@ -985,7 +985,7 @@ scode_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   INVOKE_INTERFACE_DECLS
 
   Rdl = (OBJECT_ADDRESS (Rvl));
@@ -1032,7 +1032,7 @@ scode_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd8;
   machine_word Wrd7;
   INVOKE_INTERFACE_DECLS
@@ -1096,7 +1096,7 @@ scode_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd10;
   machine_word Wrd9;
   machine_word Wrd8;
@@ -1179,7 +1179,7 @@ scode_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd8;
   machine_word Wrd7;
   INVOKE_INTERFACE_DECLS
@@ -1239,7 +1239,7 @@ scode_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   INVOKE_INTERFACE_DECLS
 
   Rdl = (OBJECT_ADDRESS (Rvl));
@@ -1287,7 +1287,7 @@ scode_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd9;
   machine_word Wrd8;
   machine_word Wrd5;
@@ -1376,7 +1376,7 @@ scode_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd10;
   machine_word Wrd9;
   machine_word Wrd19;
@@ -1546,7 +1546,7 @@ scode_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd21;
   machine_word Wrd12;
   machine_word Wrd25;
@@ -1956,7 +1956,7 @@ scode_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd14;
   machine_word Wrd10;
   machine_word Wrd5;
@@ -2067,11 +2067,11 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-scode_so_e3bde7c1d860f73c (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+scode_so_19dc3bdba5156027 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd8;
   machine_word Wrd6;
   machine_word Wrd5;
@@ -2162,7 +2162,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_scode_so_e3bde7c1d860f73c [18] =
+static const struct liarc_code_S arr_decl_scode_so_19dc3bdba5156027 [18] =
   {
     { "scode_so_code_1", 1, scode_so_code_1 },
     { "scode_so_code_2", 1, scode_so_code_2 },
@@ -2185,19 +2185,19 @@ static const struct liarc_code_S arr_decl_scode_so_e3bde7c1d860f73c [18] =
   };
 
 int
-decl_scode_so_e3bde7c1d860f73c (void)
+decl_scode_so_19dc3bdba5156027 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_scode_so_e3bde7c1d860f73c);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_scode_so_19dc3bdba5156027);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("scode.so", 3, decl_scode_so_e3bde7c1d860f73c, scode_so_e3bde7c1d860f73c)
+DECLARE_COMPILED_CODE ("scode.so", 3, decl_scode_so_19dc3bdba5156027, scode_so_19dc3bdba5156027)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_scode_so_data_e3bde7c1d860f73c [2142] =
+static const unsigned char prog_scode_so_data_19dc3bdba5156027 [2142] =
   "\x4d\x23\xec\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29\x21\x9c"
   "\x2b\xb9\x1d\xb0\x82\x88\x22\x29\x21\x9c\x2b\xba\x1d\xb0\x83\x88"
   "\x28\x0d\x23\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x84\x88\x08"
@@ -2230,9 +2230,9 @@ static const unsigned char prog_scode_so_data_e3bde7c1d860f73c [2142] =
   "\x0d\x0d\x0d\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b\xb5\x0d\xb4"
   "\x0d\x0d\x0d\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02"
   "\x58\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74"
-  "\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65"
-  "\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63"
-  "\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63"
+  "\x77\x61\x72\x65\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2f"
+  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x32\x2f\x6d\x69\x74\x2d"
+  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x32\x2f\x73\x72\x63"
   "\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61\x73\x65\x2f\x73"
   "\x63\x6f\x64\x65\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66"
   "\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x04\x04"
@@ -2334,19 +2334,19 @@ static const unsigned char prog_scode_so_data_e3bde7c1d860f73c [2142] =
   "\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-scode_so_data_e3bde7c1d860f73c (entry_count_t dispatch_base)
+scode_so_data_19dc3bdba5156027 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_scode_so_data_e3bde7c1d860f73c [0]))), (sizeof (prog_scode_so_data_e3bde7c1d860f73c)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_scode_so_data_19dc3bdba5156027 [0]))), (sizeof (prog_scode_so_data_19dc3bdba5156027)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("scode.so", scode_so_data_e3bde7c1d860f73c)
+DECLARE_COMPILED_DATA_NS ("scode.so", scode_so_data_19dc3bdba5156027)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("scode.so", "bfe638471865dbd3")
+DECLARE_DYNAMIC_INITIALIZATION ("scode.so", "d9590ac45d5629a8")
