@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:38-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:15-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -40,7 +40,7 @@ envopt_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd46;
   machine_word Wrd45;
   machine_word Wrd44;
@@ -380,7 +380,7 @@ envopt_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd10;
   machine_word Wrd26;
   machine_word Wrd21;
@@ -1025,7 +1025,7 @@ envopt_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd10;
   machine_word Wrd24;
   machine_word Wrd21;
@@ -1492,7 +1492,7 @@ envopt_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd70;
   machine_word Wrd67;
   machine_word Wrd66;
@@ -1771,7 +1771,7 @@ envopt_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd28;
   machine_word Wrd25;
   machine_word Wrd24;
@@ -2235,11 +2235,11 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-envopt_so_f000e54c3f04722d (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+envopt_so_07d94447041773a6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd8;
   machine_word Wrd6;
   machine_word Wrd5;
@@ -2317,7 +2317,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_envopt_so_f000e54c3f04722d [5] =
+static const struct liarc_code_S arr_decl_envopt_so_07d94447041773a6 [5] =
   {
     { "envopt_so_code_1", 12, envopt_so_code_1 },
     { "envopt_so_code_2", 20, envopt_so_code_2 },
@@ -2327,19 +2327,19 @@ static const struct liarc_code_S arr_decl_envopt_so_f000e54c3f04722d [5] =
   };
 
 int
-decl_envopt_so_f000e54c3f04722d (void)
+decl_envopt_so_07d94447041773a6 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_envopt_so_f000e54c3f04722d);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_envopt_so_07d94447041773a6);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("envopt.so", 3, decl_envopt_so_f000e54c3f04722d, envopt_so_f000e54c3f04722d)
+DECLARE_COMPILED_CODE ("envopt.so", 3, decl_envopt_so_07d94447041773a6, envopt_so_07d94447041773a6)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_envopt_so_data_f000e54c3f04722d [1283] =
+static const unsigned char prog_envopt_so_data_07d94447041773a6 [1283] =
   "\x44\x0d\xa9\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc3\xb9\x1d\xc2"
   "\xba\x83\x02\x0d\x0d\x0d\xbb\x0d\xbc\x0d\xbd\x24\x28\x0d\x28\x0d"
   "\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
@@ -2360,9 +2360,9 @@ static const unsigned char prog_envopt_so_data_f000e54c3f04722d [1283] =
   "\xb7\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb6\x2a\x9c\x1b\xb5\xb4\xb3\x0d"
   "\x9c\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5a\x2f\x55"
   "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72"
-  "\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65"
-  "\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
-  "\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f"
+  "\x65\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c"
+  "\x65\x61\x73\x65\x2d\x39\x2e\x32\x2f\x6d\x69\x74\x2d\x73\x63\x68"
+  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x32\x2f\x73\x72\x63\x2f\x63\x6f"
   "\x6d\x70\x69\x6c\x65\x72\x2f\x66\x67\x6f\x70\x74\x2f\x65\x6e\x76"
   "\x6f\x70\x74\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69"
   "\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0c\x76\x65"
@@ -2423,19 +2423,19 @@ static const unsigned char prog_envopt_so_data_f000e54c3f04722d [1283] =
   "\x02\x07\x11";
 
 SCHEME_OBJECT *
-envopt_so_data_f000e54c3f04722d (entry_count_t dispatch_base)
+envopt_so_data_07d94447041773a6 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_envopt_so_data_f000e54c3f04722d [0]))), (sizeof (prog_envopt_so_data_f000e54c3f04722d)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_envopt_so_data_07d94447041773a6 [0]))), (sizeof (prog_envopt_so_data_07d94447041773a6)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("envopt.so", envopt_so_data_f000e54c3f04722d)
+DECLARE_COMPILED_DATA_NS ("envopt.so", envopt_so_data_07d94447041773a6)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("envopt.so", "54dc16635d3c44de")
+DECLARE_DYNAMIC_INITIALIZATION ("envopt.so", "873cdb28d666e2ca")
