@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:38-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:15-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -28,7 +28,7 @@ folcon_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd5;
   machine_word Wrd10;
   machine_word Wrd14;
@@ -217,7 +217,7 @@ folcon_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd92;
   machine_word Wrd89;
   machine_word Wrd88;
@@ -703,7 +703,7 @@ folcon_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd35;
   machine_word Wrd33;
   machine_word Wrd18;
@@ -1134,7 +1134,7 @@ folcon_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd33;
   machine_word Wrd32;
   machine_word Wrd26;
@@ -1311,9 +1311,9 @@ DEFLABEL (fold_combination_25)
   (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
   (Wrd12.Obj) = ((Wrd11.pObj) [0]);
   (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
-  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd13.Lng))))
+  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd13.Lng))))
     goto label_55;
-  (Wrd5.Obj) = ((Wrd11.pObj) [9]);
+  (Wrd5.Obj) = ((Wrd11.pObj) [11]);
 
 DEFLABEL (label_54)
   (Wrd23.uLng) = (OBJECT_TYPE (Wrd5.Obj));
@@ -1331,9 +1331,9 @@ DEFLABEL (label_52)
   (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
   (Wrd35.Obj) = ((Wrd34.pObj) [0]);
   (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
-  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd36.Lng))))
+  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd36.Lng))))
     goto label_51;
-  (Wrd28.Obj) = ((Wrd34.pObj) [9]);
+  (Wrd28.Obj) = ((Wrd34.pObj) [11]);
 
 DEFLABEL (label_50)
   (Wrd46.uLng) = (OBJECT_TYPE (Wrd28.Obj));
@@ -1351,9 +1351,9 @@ DEFLABEL (label_48)
   (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd60.Obj));
   (Wrd58.Obj) = ((Wrd57.pObj) [0]);
   (Wrd59.Lng) = (FIXNUM_TO_LONG (Wrd58.Obj));
-  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd59.Lng))))
+  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd59.Lng))))
     goto label_47;
-  (Wrd53.Obj) = ((Wrd57.pObj) [8]);
+  (Wrd53.Obj) = ((Wrd57.pObj) [10]);
   (* (--Rsp)) = (Wrd53.Obj);
 
 DEFLABEL (label_46)
@@ -1706,7 +1706,7 @@ folcon_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd5;
   machine_word Wrd23;
   machine_word Wrd22;
@@ -2044,7 +2044,7 @@ folcon_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd11;
   machine_word Wrd17;
   machine_word Wrd15;
@@ -2275,7 +2275,7 @@ folcon_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd29;
   machine_word Wrd28;
   machine_word Wrd44;
@@ -2672,7 +2672,7 @@ folcon_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd56;
   machine_word Wrd53;
   machine_word Wrd44;
@@ -2871,7 +2871,7 @@ folcon_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd49;
   machine_word Wrd45;
   machine_word Wrd57;
@@ -3098,11 +3098,11 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-folcon_so_8fc84afd89943e50 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+folcon_so_8aa2580651c9fd26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd8;
   machine_word Wrd6;
   machine_word Wrd5;
@@ -3184,7 +3184,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_folcon_so_8fc84afd89943e50 [9] =
+static const struct liarc_code_S arr_decl_folcon_so_8aa2580651c9fd26 [9] =
   {
     { "folcon_so_code_1", 7, folcon_so_code_1 },
     { "folcon_so_code_2", 15, folcon_so_code_2 },
@@ -3198,19 +3198,19 @@ static const struct liarc_code_S arr_decl_folcon_so_8fc84afd89943e50 [9] =
   };
 
 int
-decl_folcon_so_8fc84afd89943e50 (void)
+decl_folcon_so_8aa2580651c9fd26 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_folcon_so_8fc84afd89943e50);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_folcon_so_8aa2580651c9fd26);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("folcon.so", 3, decl_folcon_so_8fc84afd89943e50, folcon_so_8fc84afd89943e50)
+DECLARE_COMPILED_CODE ("folcon.so", 3, decl_folcon_so_8aa2580651c9fd26, folcon_so_8aa2580651c9fd26)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_folcon_so_data_8fc84afd89943e50 [2256] =
+static const unsigned char prog_folcon_so_data_8aa2580651c9fd26 [2256] =
   "\x64\x17\xf7\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\x24\x28\x0d"
   "\x28\x0d\xb9\x28\x0d\xba\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x82\x88\x07"
@@ -3244,9 +3244,9 @@ static const unsigned char prog_folcon_so_data_8fc84afd89943e50 [2256] =
   "\x1b\x2a\xb3\x2a\x17\x1b\x1b\x1b\x1b\x1b\x1b\xb2\xb1\x0d\x17\x28"
   "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5a\x2f\x55\x73\x65"
   "\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f"
-  "\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
-  "\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
-  "\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70"
+  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61"
+  "\x73\x65\x2d\x39\x2e\x32\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
+  "\x65\x2d\x63\x2d\x39\x2e\x32\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70"
   "\x69\x6c\x65\x72\x2f\x66\x67\x6f\x70\x74\x2f\x66\x6f\x6c\x63\x6f"
   "\x6e\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61"
   "\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x19\x61\x70\x70\x6c"
@@ -3285,7 +3285,7 @@ static const unsigned char prog_folcon_so_data_8fc84afd89943e50 [2256] =
   "\x87\x02\x1a\x04\x83\x04\x19\x2c\x0c\x02\x0c\x02\x2c\x66\x6f\x6c"
   "\x64\x2d\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x3a\x20\x57"
   "\x72\x6f\x6e\x67\x20\x6e\x75\x6d\x62\x65\x72\x20\x6f\x66\x20\x61"
-  "\x72\x67\x75\x6d\x65\x6e\x74\x73\x06\x61\x70\x70\x6c\x79\x08\x09"
+  "\x72\x67\x75\x6d\x65\x6e\x74\x73\x06\x61\x70\x70\x6c\x79\x0a\x0b"
   "\x17\x72\x76\x61\x6c\x75\x65\x2d\x6b\x6e\x6f\x77\x6e\x2d\x63\x6f"
   "\x6e\x73\x74\x61\x6e\x74\x3f\x0d\x16\x72\x76\x61\x6c\x75\x65\x2d"
   "\x63\x6f\x6e\x73\x74\x61\x6e\x74\x2d\x76\x61\x6c\x75\x65\x0e\x03"
@@ -3354,19 +3354,19 @@ static const unsigned char prog_folcon_so_data_8fc84afd89943e50 [2256] =
   "\x08\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-folcon_so_data_8fc84afd89943e50 (entry_count_t dispatch_base)
+folcon_so_data_8aa2580651c9fd26 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_folcon_so_data_8fc84afd89943e50 [0]))), (sizeof (prog_folcon_so_data_8fc84afd89943e50)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_folcon_so_data_8aa2580651c9fd26 [0]))), (sizeof (prog_folcon_so_data_8aa2580651c9fd26)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("folcon.so", folcon_so_data_8fc84afd89943e50)
+DECLARE_COMPILED_DATA_NS ("folcon.so", folcon_so_data_8aa2580651c9fd26)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("folcon.so", "89d23c2ade262f05")
+DECLARE_DYNAMIC_INITIALIZATION ("folcon.so", "25554cd76fd3cdae")
