@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:38-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:15-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -158,11 +158,11 @@
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-outer_so_7df024178fe5dac3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+outer_so_2998375ed3a84b78 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd92;
   machine_word Wrd94;
   machine_word Wrd93;
@@ -582,7 +582,7 @@ DEFLABEL (perform_dispatch)
 
     case 70:
       current_block = (Rpc - LABEL_87);
-      goto continuation_83;
+      goto continuation_85;
 
     case 71:
       current_block = (Rpc - LABEL_99);
@@ -634,7 +634,7 @@ DEFLABEL (perform_dispatch)
 
     case 83:
       current_block = (Rpc - LABEL_98);
-      goto lambda_85;
+      goto lambda_87;
 
     case 84:
       current_block = (Rpc - LABEL_112);
@@ -920,9 +920,9 @@ DEFLABEL (prepare_application_35)
   (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
   (Wrd36.Obj) = ((Wrd35.pObj) [0]);
   (Wrd37.Lng) = (FIXNUM_TO_LONG (Wrd36.Obj));
-  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd37.Lng))))
+  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd37.Lng))))
     goto label_194;
-  ((Wrd35.pObj) [11]) = ((SCHEME_OBJECT) 0);
+  ((Wrd35.pObj) [13]) = ((SCHEME_OBJECT) 0);
 
 DEFLABEL (label_193)
   (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28]))));
@@ -938,9 +938,9 @@ DEFLABEL (label_193)
   (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
   (Wrd20.Obj) = ((Wrd19.pObj) [0]);
   (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd20.Obj));
-  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd21.Lng))))
+  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd21.Lng))))
     goto label_192;
-  (Wrd15.Obj) = ((Wrd19.pObj) [8]);
+  (Wrd15.Obj) = ((Wrd19.pObj) [10]);
   (* (--Rsp)) = (Wrd15.Obj);
 
 DEFLABEL (label_191)
@@ -967,10 +967,10 @@ DEFLABEL (label_186)
   (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
   (Wrd33.Obj) = ((Wrd32.pObj) [0]);
   (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
-  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd34.Lng))))
+  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd34.Lng))))
     goto label_190;
   (Wrd28.Obj) = (current_block [OBJECT_21]);
-  ((Wrd32.pObj) [11]) = (Wrd28.Obj);
+  ((Wrd32.pObj) [13]) = (Wrd28.Obj);
 
 DEFLABEL (label_189)
   (Wrd8.Obj) = (Rsp [0]);
@@ -984,9 +984,9 @@ DEFLABEL (label_189)
   (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
   (Wrd17.Obj) = ((Wrd16.pObj) [0]);
   (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
-  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd18.Lng))))
+  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd18.Lng))))
     goto label_188;
-  (Wrd10.Obj) = ((Wrd16.pObj) [9]);
+  (Wrd10.Obj) = ((Wrd16.pObj) [11]);
 
 DEFLABEL (label_187)
   (Rsp [1]) = (Wrd10.Obj);
@@ -994,7 +994,7 @@ DEFLABEL (label_187)
 
 DEFLABEL (label_188)
   (Wrd21.Obj) = (Rsp [1]);
-  (Wrd22.Obj) = (current_block [OBJECT_12]);
+  (Wrd22.Obj) = (current_block [OBJECT_22]);
   (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76]))));
   (* (--Rsp)) = (Wrd25.Obj);
   (* (--Rsp)) = (Wrd22.Obj);
@@ -1059,9 +1059,9 @@ DEFLABEL (check_application_41)
   (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
   (Wrd15.Obj) = ((Wrd14.pObj) [0]);
   (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
-  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd16.Lng))))
+  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd16.Lng))))
     goto label_204;
-  (Wrd10.Obj) = ((Wrd14.pObj) [8]);
+  (Wrd10.Obj) = ((Wrd14.pObj) [10]);
   (* (--Rsp)) = (Wrd10.Obj);
 
 DEFLABEL (label_203)
@@ -1085,9 +1085,9 @@ DEFLABEL (label_196)
   (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
   (Wrd53.Obj) = ((Wrd52.pObj) [0]);
   (Wrd54.Lng) = (FIXNUM_TO_LONG (Wrd53.Obj));
-  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd54.Lng))))
+  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd54.Lng))))
     goto label_202;
-  (Wrd9.Obj) = ((Wrd52.pObj) [11]);
+  (Wrd9.Obj) = ((Wrd52.pObj) [13]);
   if (! ((Wrd9.Obj) == ((SCHEME_OBJECT) 0)))
     goto label_195;
 
@@ -1099,10 +1099,10 @@ DEFLABEL (label_201)
   (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
   (Wrd37.Obj) = ((Wrd36.pObj) [0]);
   (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
-  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd38.Lng))))
+  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd38.Lng))))
     goto label_200;
   (Wrd32.Obj) = (current_block [OBJECT_21]);
-  ((Wrd36.pObj) [11]) = (Wrd32.Obj);
+  ((Wrd36.pObj) [13]) = (Wrd32.Obj);
 
 DEFLABEL (label_199)
   (Wrd12.Obj) = (Rsp [0]);
@@ -1116,9 +1116,9 @@ DEFLABEL (label_199)
   (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
   (Wrd21.Obj) = ((Wrd20.pObj) [0]);
   (Wrd22.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
-  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd22.Lng))))
+  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd22.Lng))))
     goto label_198;
-  (Wrd14.Obj) = ((Wrd20.pObj) [9]);
+  (Wrd14.Obj) = ((Wrd20.pObj) [11]);
 
 DEFLABEL (label_197)
   (Rsp [1]) = (Wrd14.Obj);
@@ -1126,7 +1126,7 @@ DEFLABEL (label_197)
 
 DEFLABEL (label_198)
   (Wrd25.Obj) = (Rsp [1]);
-  (Wrd26.Obj) = (current_block [OBJECT_12]);
+  (Wrd26.Obj) = (current_block [OBJECT_22]);
   (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82]))));
   (* (--Rsp)) = (Wrd29.Obj);
   (* (--Rsp)) = (Wrd26.Obj);
@@ -1463,7 +1463,7 @@ DEFLABEL (label_216)
 
 DEFLABEL (label_217)
   (Wrd40.Obj) = (Rsp [2]);
-  (Wrd41.Obj) = (current_block [OBJECT_22]);
+  (Wrd41.Obj) = (current_block [OBJECT_5]);
   (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84]))));
   (* (--Rsp)) = (Wrd44.Obj);
   (* (--Rsp)) = (Wrd41.Obj);
@@ -1554,7 +1554,7 @@ DEFLABEL (label_224)
   (Wrd140.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51]))));
   (* (--Rsp)) = (Wrd140.Obj);
   (* (--Rsp)) = (Wrd118.Obj);
-  INVOKE_PRIMITIVE ((current_block [OBJECT_14]), 1);
+  INVOKE_PRIMITIVE ((current_block [OBJECT_15]), 1);
 
 DEFLABEL (label_128)
   (Wrd134.Obj) = Rvl;
@@ -1562,7 +1562,7 @@ DEFLABEL (label_128)
 
 DEFLABEL (label_226)
   (Wrd129.Obj) = (Rsp [0]);
-  (Wrd130.Obj) = (current_block [OBJECT_13]);
+  (Wrd130.Obj) = (current_block [OBJECT_14]);
   (Wrd133.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50]))));
   (* (--Rsp)) = (Wrd133.Obj);
   (* (--Rsp)) = (Wrd130.Obj);
@@ -1615,7 +1615,7 @@ DEFLABEL (label_123)
 
 DEFLABEL (label_236)
   (Wrd63.Obj) = (Rsp [3]);
-  (Wrd64.Obj) = (current_block [OBJECT_5]);
+  (Wrd64.Obj) = (current_block [OBJECT_13]);
   (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45]))));
   (* (--Rsp)) = (Wrd67.Obj);
   (* (--Rsp)) = (Wrd64.Obj);
@@ -1737,7 +1737,7 @@ DEFLABEL (label_248)
   (* (--Rsp)) = (Wrd37.Obj);
 
 DEFLABEL (label_249)
-  (Wrd51.Obj) = (current_block [OBJECT_16]);
+  (Wrd51.Obj) = (current_block [OBJECT_17]);
   (* (--Rsp)) = (Wrd51.Obj);
   JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60]));
 
@@ -1749,7 +1749,7 @@ DEFLABEL (continuation_79)
 
 DEFLABEL (label_250)
   (Wrd46.Obj) = (Rsp [2]);
-  (Wrd47.Obj) = (current_block [OBJECT_15]);
+  (Wrd47.Obj) = (current_block [OBJECT_16]);
   (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59]))));
   (* (--Rsp)) = (Wrd50.Obj);
   (* (--Rsp)) = (Wrd47.Obj);
@@ -1882,7 +1882,7 @@ DEFLABEL (label_134)
 
 DEFLABEL (label_260)
   (Wrd64.Obj) = (Rsp [1]);
-  (Wrd65.Obj) = (current_block [OBJECT_17]);
+  (Wrd65.Obj) = (current_block [OBJECT_3]);
   (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_63]))));
   (* (--Rsp)) = (Wrd69.Obj);
   (* (--Rsp)) = (Wrd32.Obj);
@@ -1899,7 +1899,7 @@ DEFLABEL (label_263)
 
 DEFLABEL (label_265)
   (Wrd19.Obj) = (Rsp [2]);
-  (Wrd20.Obj) = (current_block [OBJECT_17]);
+  (Wrd20.Obj) = (current_block [OBJECT_3]);
   (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62]))));
   (* (--Rsp)) = (Wrd23.Obj);
   (* (--Rsp)) = (Wrd20.Obj);
@@ -2205,7 +2205,7 @@ DEFLABEL (label_296)
   (* (--Rsp)) = (Wrd70.Obj);
   goto Z__lvalue_passed_inB_95;
 
-DEFLABEL (continuation_83)
+DEFLABEL (continuation_85)
   INTERRUPT_CHECK (27, LABEL_87);
   (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98]))));
   (Rsp [0]) = (Wrd5.Obj);
@@ -2226,7 +2226,7 @@ DEFLABEL (label_287)
 
 DEFLABEL (label_288)
   (Wrd18.Obj) = (Rsp [1]);
-  (Wrd19.Obj) = (current_block [OBJECT_13]);
+  (Wrd19.Obj) = (current_block [OBJECT_14]);
   (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99]))));
   (* (--Rsp)) = (Wrd22.Obj);
   (* (--Rsp)) = (Wrd19.Obj);
@@ -2321,7 +2321,7 @@ DEFLABEL (label_147)
 DEFLABEL (Z__lvalue_passed_outB_177)
 DEFLABEL (Z__lvalue_passed_outB_107)
   INTERRUPT_CHECK (26, LABEL_66);
-  (Wrd5.Obj) = (current_block [OBJECT_17]);
+  (Wrd5.Obj) = (current_block [OBJECT_3]);
   (* (--Rsp)) = (Wrd5.Obj);
   (Wrd6.Obj) = (Rsp [1]);
   (* (--Rsp)) = (Wrd6.Obj);
@@ -2386,7 +2386,7 @@ DEFLABEL (label_304)
 
 DEFLABEL (label_306)
   (Wrd21.Obj) = (Rsp [3]);
-  (Wrd22.Obj) = (current_block [OBJECT_17]);
+  (Wrd22.Obj) = (current_block [OBJECT_3]);
   (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92]))));
   (* (--Rsp)) = (Wrd25.Obj);
   (* (--Rsp)) = (Wrd22.Obj);
@@ -2474,7 +2474,7 @@ DEFLABEL (label_309)
 
 DEFLABEL (label_310)
   (Wrd16.Obj) = (Rsp [0]);
-  (Wrd17.Obj) = (current_block [OBJECT_3]);
+  (Wrd17.Obj) = (current_block [OBJECT_22]);
   (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102]))));
   (* (--Rsp)) = (Wrd20.Obj);
   (* (--Rsp)) = (Wrd17.Obj);
@@ -2603,7 +2603,7 @@ DEFLABEL (label_160)
 
 DEFLABEL (label_318)
   (Wrd47.Obj) = (Rsp [1]);
-  (Wrd48.Obj) = (current_block [OBJECT_13]);
+  (Wrd48.Obj) = (current_block [OBJECT_14]);
   (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_109]))));
   (* (--Rsp)) = (Wrd51.Obj);
   (* (--Rsp)) = (Wrd48.Obj);
@@ -2650,7 +2650,7 @@ DEFLABEL (continuation_17)
   goto label_321;
 
 DEFLABEL (lambda_180)
-DEFLABEL (lambda_85)
+DEFLABEL (lambda_87)
   INTERRUPT_CHECK (26, LABEL_98);
   (Wrd19.Obj) = (Rsp [0]);
   (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
@@ -2701,9 +2701,9 @@ DEFLABEL (lambda_93)
   (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
   (Wrd15.Obj) = ((Wrd14.pObj) [0]);
   (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
-  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd16.Lng))))
+  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd16.Lng))))
     goto label_331;
-  (Wrd7.Obj) = ((Wrd14.pObj) [11]);
+  (Wrd7.Obj) = ((Wrd14.pObj) [13]);
   if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
     goto label_330;
 
@@ -2768,7 +2768,7 @@ DEFLABEL (label_334)
 
 DEFLABEL (label_335)
   (Wrd22.Obj) = (Rsp [0]);
-  (Wrd23.Obj) = (current_block [OBJECT_5]);
+  (Wrd23.Obj) = (current_block [OBJECT_13]);
   (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117]))));
   (* (--Rsp)) = (Wrd26.Obj);
   (* (--Rsp)) = (Wrd23.Obj);
@@ -2781,7 +2781,7 @@ DEFLABEL (label_161)
 
 DEFLABEL (label_336)
   (Wrd35.Obj) = (Rsp [0]);
-  (Wrd36.Obj) = (current_block [OBJECT_5]);
+  (Wrd36.Obj) = (current_block [OBJECT_13]);
   (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116]))));
   (* (--Rsp)) = (Wrd39.Obj);
   (* (--Rsp)) = (Wrd36.Obj);
@@ -2798,20 +2798,20 @@ INVOKE_PRIMITIVE_TARGET
 }
 
 int
-decl_outer_so_7df024178fe5dac3 (void)
+decl_outer_so_2998375ed3a84b78 (void)
 {
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("outer.so", 96, decl_outer_so_7df024178fe5dac3, outer_so_7df024178fe5dac3)
+DECLARE_COMPILED_CODE ("outer.so", 96, decl_outer_so_2998375ed3a84b78, outer_so_2998375ed3a84b78)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_outer_so_data_7df024178fe5dac3 [1228] =
+static const unsigned char prog_outer_so_data_2998375ed3a84b78 [1228] =
   "\xf9\x01\x01\xfa\x01\x1d\x0c\x0d\x0d\x0d\x02\x02\x07\x1d\x0d\x86"
-  "\x02\x0d\x02\xc1\x85\x02\x81\x82\xc2\x83\x80\xc2\x02\xc3\x02\xc3"
+  "\x0d\x02\xc1\x85\x02\x02\x81\x82\xc2\x83\x80\xc2\x02\xc3\x02\xc3"
   "\xc3\x0d\x0d\x0d\x0d\x0d\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28"
   "\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x23\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
@@ -2827,17 +2827,17 @@ static const unsigned char prog_outer_so_data_7df024178fe5dac3 [1228] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x59"
   "\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77"
-  "\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61"
-  "\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68"
-  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f"
+  "\x61\x72\x65\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2f\x72"
+  "\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x32\x2f\x6d\x69\x74\x2d\x73"
+  "\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x32\x2f\x73\x72\x63\x2f"
   "\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x66\x67\x6f\x70\x74\x2f\x6f"
   "\x75\x74\x65\x72\x2e\x69\x6e\x66\x06\x62\x6c\x6f\x63\x6b\x0a\x70"
   "\x72\x6f\x63\x65\x64\x75\x72\x65\x0a\x69\x6e\x68\x65\x72\x69\x74"
-  "\x65\x64\x0c\x0a\x02\x0a\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x0d"
-  "\x09\x63\x6f\x6e\x73\x74\x61\x6e\x74\x14\x04\x63\x61\x72\x09\x0c"
+  "\x65\x64\x0c\x0b\x02\x0a\x72\x65\x66\x65\x72\x65\x6e\x63\x65\x09"
+  "\x63\x6f\x6e\x73\x74\x61\x6e\x74\x14\x04\x63\x61\x72\x08\x09\x0c"
   "\x25\x72\x65\x63\x6f\x72\x64\x2d\x72\x65\x66\x0b\x76\x65\x63\x74"
-  "\x6f\x72\x2d\x72\x65\x66\x08\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73"
-  "\x65\x74\x21\x0b\x13\x6c\x65\x78\x69\x63\x61\x6c\x2d\x61\x73\x73"
+  "\x6f\x72\x2d\x72\x65\x66\x0a\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73"
+  "\x65\x74\x21\x0d\x13\x6c\x65\x78\x69\x63\x61\x6c\x2d\x61\x73\x73"
   "\x69\x67\x6e\x6d\x65\x6e\x74\x11\x6c\x6f\x63\x61\x6c\x2d\x61\x73"
   "\x73\x69\x67\x6e\x6d\x65\x6e\x74\x0f\x6f\x75\x74\x65\x72\x2d\x61"
   "\x6e\x61\x6c\x79\x73\x69\x73\x0d\x72\x76\x61\x6c\x75\x65\x2d\x74"
@@ -2889,19 +2889,19 @@ static const unsigned char prog_outer_so_data_7df024178fe5dac3 [1228] =
   "\x81\x91\x02\x01\x04\x81\x83\x02\xc1\x01\xf9\x01";
 
 SCHEME_OBJECT *
-outer_so_data_7df024178fe5dac3 (entry_count_t dispatch_base)
+outer_so_data_2998375ed3a84b78 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_outer_so_data_7df024178fe5dac3 [0]))), (sizeof (prog_outer_so_data_7df024178fe5dac3)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_outer_so_data_2998375ed3a84b78 [0]))), (sizeof (prog_outer_so_data_2998375ed3a84b78)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_119]));
 }
 
-DECLARE_COMPILED_DATA_NS ("outer.so", outer_so_data_7df024178fe5dac3)
+DECLARE_COMPILED_DATA_NS ("outer.so", outer_so_data_2998375ed3a84b78)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("outer.so", "4d0c4173231d96b4")
+DECLARE_DYNAMIC_INITIALIZATION ("outer.so", "e139a8b91971d8b2")
