@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:40-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:16-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -33,7 +33,7 @@ varind_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd62;
   machine_word Wrd59;
   machine_word Wrd58;
@@ -327,7 +327,7 @@ varind_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd9;
   machine_word Wrd41;
   machine_word Wrd39;
@@ -1396,11 +1396,11 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-varind_so_97a7e83f1cfea0b8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+varind_so_3dc7a8316536d629 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd8;
   machine_word Wrd6;
   machine_word Wrd5;
@@ -1475,26 +1475,26 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_varind_so_97a7e83f1cfea0b8 [2] =
+static const struct liarc_code_S arr_decl_varind_so_3dc7a8316536d629 [2] =
   {
     { "varind_so_code_1", 7, varind_so_code_1 },
     { "varind_so_code_2", 33, varind_so_code_2 }
   };
 
 int
-decl_varind_so_97a7e83f1cfea0b8 (void)
+decl_varind_so_3dc7a8316536d629 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_varind_so_97a7e83f1cfea0b8);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_varind_so_3dc7a8316536d629);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("varind.so", 3, decl_varind_so_97a7e83f1cfea0b8, varind_so_97a7e83f1cfea0b8)
+DECLARE_COMPILED_CODE ("varind.so", 3, decl_varind_so_3dc7a8316536d629, varind_so_3dc7a8316536d629)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_varind_so_data_97a7e83f1cfea0b8 [801] =
+static const unsigned char prog_varind_so_data_3dc7a8316536d629 [801] =
   "\x6a\x06\xae\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x1d\x0d\x0d\x02"
   "\xc2\xb9\x80\x0d\xba\x24\x28\x0d\x28\x0d\x28\x0d\xbb\x23\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbc"
@@ -1507,9 +1507,9 @@ static const unsigned char prog_varind_so_data_97a7e83f1cfea0b8 [801] =
   "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xba\x99\xb9\x88\xb1\xb2\x2a"
   "\xb4\x2a\x99\xb3\x0d\x99\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21"
   "\x17\x02\x5a\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f"
-  "\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65"
-  "\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d"
-  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73"
+  "\x66\x74\x77\x61\x72\x65\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
+  "\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x32\x2f\x6d\x69"
+  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x32\x2f\x73"
   "\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x66\x67\x6f\x70"
   "\x74\x2f\x76\x61\x72\x69\x6e\x64\x2e\x69\x6e\x66\x15\x23\x5b\x70"
   "\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74"
@@ -1548,19 +1548,19 @@ static const unsigned char prog_varind_so_data_97a7e83f1cfea0b8 [801] =
   "\x11";
 
 SCHEME_OBJECT *
-varind_so_data_97a7e83f1cfea0b8 (entry_count_t dispatch_base)
+varind_so_data_3dc7a8316536d629 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_varind_so_data_97a7e83f1cfea0b8 [0]))), (sizeof (prog_varind_so_data_97a7e83f1cfea0b8)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_varind_so_data_3dc7a8316536d629 [0]))), (sizeof (prog_varind_so_data_3dc7a8316536d629)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("varind.so", varind_so_data_97a7e83f1cfea0b8)
+DECLARE_COMPILED_DATA_NS ("varind.so", varind_so_data_3dc7a8316536d629)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("varind.so", "577c31c728d40ae5")
+DECLARE_DYNAMIC_INITIALIZATION ("varind.so", "fcca25f699bb3365")
