@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:43-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:18-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -28,7 +28,7 @@ rgspcm_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd14;
   machine_word Wrd8;
   machine_word Wrd13;
@@ -230,7 +230,7 @@ rgspcm_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd10;
   machine_word Wrd14;
   machine_word Wrd8;
@@ -336,7 +336,7 @@ rgspcm_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd7;
   machine_word Wrd12;
   machine_word Wrd11;
@@ -439,11 +439,11 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-rgspcm_so_a64026ccabba02ad (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+rgspcm_so_ec6bcb27d8dec1e8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd7;
   machine_word Wrd10;
   machine_word Wrd9;
@@ -689,7 +689,7 @@ DEFLABEL (continuation_13)
 INVOKE_INTERFACE_TARGET_1
 }
 
-static const struct liarc_code_S arr_decl_rgspcm_so_a64026ccabba02ad [3] =
+static const struct liarc_code_S arr_decl_rgspcm_so_ec6bcb27d8dec1e8 [3] =
   {
     { "rgspcm_so_code_1", 7, rgspcm_so_code_1 },
     { "rgspcm_so_code_2", 3, rgspcm_so_code_2 },
@@ -697,19 +697,19 @@ static const struct liarc_code_S arr_decl_rgspcm_so_a64026ccabba02ad [3] =
   };
 
 int
-decl_rgspcm_so_a64026ccabba02ad (void)
+decl_rgspcm_so_ec6bcb27d8dec1e8 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_rgspcm_so_a64026ccabba02ad);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_rgspcm_so_ec6bcb27d8dec1e8);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("rgspcm.so", 17, decl_rgspcm_so_a64026ccabba02ad, rgspcm_so_a64026ccabba02ad)
+DECLARE_COMPILED_CODE ("rgspcm.so", 17, decl_rgspcm_so_ec6bcb27d8dec1e8, rgspcm_so_ec6bcb27d8dec1e8)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_rgspcm_so_data_a64026ccabba02ad [733] =
+static const unsigned char prog_rgspcm_so_data_ec6bcb27d8dec1e8 [733] =
   "\x3e\x07\x98\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc2\x07\x0d\xb9"
   "\x25\xb1\x24\x28\x0d\x28\x0d\xba\x23\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x82\x88\xc1"
@@ -721,9 +721,9 @@ static const unsigned char prog_rgspcm_so_data_a64026ccabba02ad [733] =
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5f\x2f\x55\x73"
   "\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65"
-  "\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
-  "\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
-  "\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65"
+  "\x61\x73\x65\x2d\x39\x2e\x32\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65"
+  "\x6d\x65\x2d\x63\x2d\x39\x2e\x32\x2f\x73\x72\x63\x2f\x63\x6f\x6d"
   "\x70\x69\x6c\x65\x72\x2f\x6d\x61\x63\x68\x69\x6e\x65\x73\x2f\x43"
   "\x2f\x72\x67\x73\x70\x63\x6d\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75"
   "\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d"
@@ -758,19 +758,19 @@ static const unsigned char prog_rgspcm_so_data_a64026ccabba02ad [733] =
   "\x02\x02\x06\x81\x83\x02\x01\x04\x81\x83\x02\x23\x3e";
 
 SCHEME_OBJECT *
-rgspcm_so_data_a64026ccabba02ad (entry_count_t dispatch_base)
+rgspcm_so_data_ec6bcb27d8dec1e8 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_rgspcm_so_data_a64026ccabba02ad [0]))), (sizeof (prog_rgspcm_so_data_a64026ccabba02ad)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_rgspcm_so_data_ec6bcb27d8dec1e8 [0]))), (sizeof (prog_rgspcm_so_data_ec6bcb27d8dec1e8)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_22]));
 }
 
-DECLARE_COMPILED_DATA_NS ("rgspcm.so", rgspcm_so_data_a64026ccabba02ad)
+DECLARE_COMPILED_DATA_NS ("rgspcm.so", rgspcm_so_data_ec6bcb27d8dec1e8)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("rgspcm.so", "352cedd97422015f")
+DECLARE_DYNAMIC_INITIALIZATION ("rgspcm.so", "5012700c70d1d212")
