@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:45-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:20-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -17,7 +17,7 @@ regset_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd5;
   INVOKE_INTERFACE_DECLS
   INVOKE_PRIMITIVE_DECLS
@@ -76,7 +76,7 @@ regset_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd5;
   machine_word Wrd14;
   machine_word Wrd12;
@@ -243,7 +243,7 @@ regset_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd19;
   machine_word Wrd26;
   machine_word Wrd22;
@@ -435,7 +435,7 @@ regset_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd5;
   INVOKE_INTERFACE_DECLS
   INVOKE_PRIMITIVE_DECLS
@@ -488,7 +488,7 @@ regset_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd9;
   machine_word Wrd8;
   machine_word Wrd7;
@@ -613,11 +613,11 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-regset_so_fa8cd6016f331273 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+regset_so_7e6c64cc658dd2c9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd6;
   machine_word Wrd15;
   machine_word Wrd14;
@@ -1180,7 +1180,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_regset_so_fa8cd6016f331273 [5] =
+static const struct liarc_code_S arr_decl_regset_so_7e6c64cc658dd2c9 [5] =
   {
     { "regset_so_code_1", 1, regset_so_code_1 },
     { "regset_so_code_2", 6, regset_so_code_2 },
@@ -1190,19 +1190,19 @@ static const struct liarc_code_S arr_decl_regset_so_fa8cd6016f331273 [5] =
   };
 
 int
-decl_regset_so_fa8cd6016f331273 (void)
+decl_regset_so_7e6c64cc658dd2c9 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_regset_so_fa8cd6016f331273);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_regset_so_7e6c64cc658dd2c9);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("regset.so", 31, decl_regset_so_fa8cd6016f331273, regset_so_fa8cd6016f331273)
+DECLARE_COMPILED_CODE ("regset.so", 31, decl_regset_so_7e6c64cc658dd2c9, regset_so_7e6c64cc658dd2c9)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_regset_so_data_fa8cd6016f331273 [1235] =
+static const unsigned char prog_regset_so_data_7e6c64cc658dd2c9 [1235] =
   "\x67\x08\xd4\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc2\x22\x29\x21"
   "\x9d\x2b\xb9\x1d\xb0\x82\x88\x1d\xc3\xba\x80\xc1\xbb\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbc\x1d\xb0\x83"
@@ -1217,10 +1217,10 @@ static const unsigned char prog_regset_so_data_fa8cd6016f331273 [1235] =
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x21\x17\x02\x5c\x2f\x55\x73\x65\x72\x73\x2f"
-  "\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68"
-  "\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e"
-  "\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39"
-  "\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65"
+  "\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x6d\x69\x74"
+  "\x2d\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
+  "\x39\x2e\x32\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63"
+  "\x2d\x39\x2e\x32\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65"
   "\x72\x2f\x72\x74\x6c\x62\x61\x73\x65\x2f\x72\x65\x67\x73\x65\x74"
   "\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74"
   "\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x10\x6d\x61\x6b\x65\x2d"
@@ -1283,19 +1283,19 @@ static const unsigned char prog_regset_so_data_fa8cd6016f331273 [1235] =
   "\x02\x3f\x67";
 
 SCHEME_OBJECT *
-regset_so_data_fa8cd6016f331273 (entry_count_t dispatch_base)
+regset_so_data_7e6c64cc658dd2c9 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_regset_so_data_fa8cd6016f331273 [0]))), (sizeof (prog_regset_so_data_fa8cd6016f331273)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_regset_so_data_7e6c64cc658dd2c9 [0]))), (sizeof (prog_regset_so_data_7e6c64cc658dd2c9)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_35]));
 }
 
-DECLARE_COMPILED_DATA_NS ("regset.so", regset_so_data_fa8cd6016f331273)
+DECLARE_COMPILED_DATA_NS ("regset.so", regset_so_data_7e6c64cc658dd2c9)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("regset.so", "45bdbd0bf6e88661")
+DECLARE_DYNAMIC_INITIALIZATION ("regset.so", "0af4529fd18b4e00")
