@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:48-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:22-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -21,7 +21,7 @@ fndblk_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd5;
   machine_word Wrd9;
   machine_word Wrd8;
@@ -120,7 +120,7 @@ fndblk_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd26;
   machine_word Wrd27;
   machine_word Wrd21;
@@ -411,7 +411,7 @@ fndblk_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd21;
   machine_word Wrd17;
   machine_word Wrd15;
@@ -723,7 +723,7 @@ fndblk_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd8;
   machine_word Wrd56;
   machine_word Wrd64;
@@ -883,7 +883,7 @@ DEFLABEL (perform_dispatch)
 
     case 17:
       current_block = (Rpc - LABEL_4_22);
-      goto continuation_13;
+      goto continuation_8;
 
     case 18:
       current_block = (Rpc - LABEL_4_25);
@@ -1078,7 +1078,7 @@ DEFLABEL (continuation_6)
 DEFLABEL (label_80)
   JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_24]));
 
-DEFLABEL (continuation_13)
+DEFLABEL (continuation_8)
   INTERRUPT_CHECK (27, LABEL_4_22);
   if (Rvl == ((SCHEME_OBJECT) 0))
     goto label_61;
@@ -1487,7 +1487,7 @@ fndblk_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd5;
   machine_word Wrd10;
   machine_word Wrd9;
@@ -1818,7 +1818,7 @@ fndblk_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd56;
   machine_word Wrd57;
   machine_word Wrd60;
@@ -2029,7 +2029,7 @@ fndblk_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd12;
   machine_word Wrd6;
   machine_word Wrd23;
@@ -2242,7 +2242,7 @@ fndblk_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd12;
   machine_word Wrd6;
   machine_word Wrd9;
@@ -2390,7 +2390,7 @@ fndblk_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   INVOKE_INTERFACE_DECLS
 
   Rdl = (OBJECT_ADDRESS (Rvl));
@@ -2442,7 +2442,7 @@ fndblk_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd5;
   machine_word Wrd12;
   machine_word Wrd14;
@@ -2534,7 +2534,7 @@ fndblk_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd10;
   machine_word Wrd9;
   machine_word Wrd8;
@@ -2602,11 +2602,11 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-fndblk_so_abb57aaf9c5d8945 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+fndblk_so_195ce6f6dc30d639 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd8;
   machine_word Wrd6;
   machine_word Wrd5;
@@ -2690,7 +2690,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_fndblk_so_abb57aaf9c5d8945 [11] =
+static const struct liarc_code_S arr_decl_fndblk_so_195ce6f6dc30d639 [11] =
   {
     { "fndblk_so_code_1", 3, fndblk_so_code_1 },
     { "fndblk_so_code_2", 8, fndblk_so_code_2 },
@@ -2706,19 +2706,19 @@ static const struct liarc_code_S arr_decl_fndblk_so_abb57aaf9c5d8945 [11] =
   };
 
 int
-decl_fndblk_so_abb57aaf9c5d8945 (void)
+decl_fndblk_so_195ce6f6dc30d639 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_fndblk_so_abb57aaf9c5d8945);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_fndblk_so_195ce6f6dc30d639);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("fndblk.so", 3, decl_fndblk_so_abb57aaf9c5d8945, fndblk_so_abb57aaf9c5d8945)
+DECLARE_COMPILED_CODE ("fndblk.so", 3, decl_fndblk_so_195ce6f6dc30d639, fndblk_so_195ce6f6dc30d639)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_fndblk_so_data_abb57aaf9c5d8945 [2004] =
+static const unsigned char prog_fndblk_so_data_195ce6f6dc30d639 [2004] =
   "\x58\x17\xb0\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\xb9\x28"
   "\x0d\xba\x28\x0d\xbb\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbc"
   "\x1d\xb0\x82\x88\x0d\x0c\x0d\xbd\x08\x0d\xc2\xbe\x82\x0c\x0d\xbf"
@@ -2747,9 +2747,9 @@ static const unsigned char prog_fndblk_so_data_abb57aaf9c5d8945 [2004] =
   "\x2a\xb1\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb4\x2a\x17\x1b\xb7\x1b\x1b"
   "\x1b\x1b\x1b\x1b\xb3\xb2\x0d\x17\x28\x0d\x26\x22\x29\x22\x29\x22"
   "\x29\x21\x17\x02\x5b\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
-  "\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f"
-  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69"
-  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31"
+  "\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x6d\x69\x74\x2d\x73\x63\x68"
+  "\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x32\x2f"
+  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x32"
   "\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x72\x74"
   "\x6c\x67\x65\x6e\x2f\x66\x6e\x64\x62\x6c\x6b\x2e\x69\x6e\x66\x15"
   "\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72"
@@ -2847,19 +2847,19 @@ static const unsigned char prog_fndblk_so_data_abb57aaf9c5d8945 [2004] =
   "\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-fndblk_so_data_abb57aaf9c5d8945 (entry_count_t dispatch_base)
+fndblk_so_data_195ce6f6dc30d639 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_fndblk_so_data_abb57aaf9c5d8945 [0]))), (sizeof (prog_fndblk_so_data_abb57aaf9c5d8945)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_fndblk_so_data_195ce6f6dc30d639 [0]))), (sizeof (prog_fndblk_so_data_195ce6f6dc30d639)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("fndblk.so", fndblk_so_data_abb57aaf9c5d8945)
+DECLARE_COMPILED_DATA_NS ("fndblk.so", fndblk_so_data_195ce6f6dc30d639)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("fndblk.so", "c856f87876f6ee1c")
+DECLARE_DYNAMIC_INITIALIZATION ("fndblk.so", "f25eb278c77f8f26")
