@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:51-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:24-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -159,11 +159,11 @@
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-ralloc_so_8f535a75f58334e2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+ralloc_so_2e0edaa2f68719e7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd99;
   machine_word Wrd116;
   machine_word Wrd93;
@@ -1406,9 +1406,9 @@ DEFLABEL (continuation_34)
   (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
   (Wrd23.Obj) = ((Wrd22.pObj) [0]);
   (Wrd24.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
-  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd24.Lng))))
+  if (! (((unsigned long) 9L) < ((unsigned long) (Wrd24.Lng))))
     goto label_224;
-  (Wrd18.Obj) = ((Wrd22.pObj) [8]);
+  (Wrd18.Obj) = ((Wrd22.pObj) [10]);
   (* (--Rsp)) = (Wrd18.Obj);
 
 DEFLABEL (label_223)
@@ -2920,18 +2920,18 @@ INVOKE_PRIMITIVE_TARGET
 }
 
 int
-decl_ralloc_so_8f535a75f58334e2 (void)
+decl_ralloc_so_2e0edaa2f68719e7 (void)
 {
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("ralloc.so", 99, decl_ralloc_so_8f535a75f58334e2, ralloc_so_8f535a75f58334e2)
+DECLARE_COMPILED_CODE ("ralloc.so", 99, decl_ralloc_so_2e0edaa2f68719e7, ralloc_so_2e0edaa2f68719e7)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_ralloc_so_data_8f535a75f58334e2 [1307] =
+static const unsigned char prog_ralloc_so_data_2e0edaa2f68719e7 [1307] =
   "\xff\x01\x02\x81\x02\x1d\x0c\x0d\xc2\x0d\xc1\xc1\xc2\x81\xc2\x08"
   "\x07\x86\x02\x85\xc2\x84\x82\xc3\x83\x0c\x02\xc2\x80\x1d\xc3\xc3"
   "\x0d\x0d\xb8\x25\xb0\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d"
@@ -2949,17 +2949,17 @@ static const unsigned char prog_ralloc_so_data_8f535a75f58334e2 [1307] =
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x21\x17\x02\x5b\x2f\x55\x73\x65\x72\x73\x2f\x63\x70"
-  "\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d"
-  "\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f"
-  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31"
-  "\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f"
+  "\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x6d\x69\x74\x2d\x73"
+  "\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
+  "\x32\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39"
+  "\x2e\x32\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f"
   "\x72\x74\x6c\x6f\x70\x74\x2f\x72\x61\x6c\x6c\x6f\x63\x2e\x69\x6e"
   "\x66\x09\x72\x65\x67\x69\x73\x74\x65\x72\x12\x62\x69\x74\x2d\x73"
   "\x74\x72\x69\x6e\x67\x2d\x63\x6c\x65\x61\x72\x21\x07\x61\x73\x73"
   "\x69\x67\x6e\x04\x63\x61\x72\x11\x62\x69\x74\x2d\x73\x74\x72\x69"
   "\x6e\x67\x2d\x7a\x65\x72\x6f\x3f\x0f\x62\x69\x74\x2d\x73\x74\x72"
   "\x69\x6e\x67\x2d\x6f\x72\x21\x10\x62\x69\x74\x2d\x73\x74\x72\x69"
-  "\x6e\x67\x2d\x73\x65\x74\x21\x08\x10\x6d\x61\x6b\x65\x2d\x62\x69"
+  "\x6e\x67\x2d\x73\x65\x74\x21\x0a\x10\x6d\x61\x6b\x65\x2d\x62\x69"
   "\x74\x2d\x73\x74\x72\x69\x6e\x67\x0c\x76\x65\x63\x74\x6f\x72\x2d"
   "\x73\x65\x74\x21\x1e\x54\x6f\x6f\x20\x6d\x61\x6e\x79\x20\x74\x65"
   "\x6d\x70\x6f\x72\x61\x72\x79\x20\x71\x75\x61\x6e\x74\x69\x74\x69"
@@ -3016,19 +3016,19 @@ static const unsigned char prog_ralloc_so_data_8f535a75f58334e2 [1307] =
   "\x83\x02\x01\x04\x81\x83\x02\xc7\x01\xff\x01";
 
 SCHEME_OBJECT *
-ralloc_so_data_8f535a75f58334e2 (entry_count_t dispatch_base)
+ralloc_so_data_2e0edaa2f68719e7 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_ralloc_so_data_8f535a75f58334e2 [0]))), (sizeof (prog_ralloc_so_data_8f535a75f58334e2)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_ralloc_so_data_2e0edaa2f68719e7 [0]))), (sizeof (prog_ralloc_so_data_2e0edaa2f68719e7)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_123]));
 }
 
-DECLARE_COMPILED_DATA_NS ("ralloc.so", ralloc_so_data_8f535a75f58334e2)
+DECLARE_COMPILED_DATA_NS ("ralloc.so", ralloc_so_data_2e0edaa2f68719e7)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("ralloc.so", "bca5118989bb6d6c")
+DECLARE_DYNAMIC_INITIALIZATION ("ralloc.so", "98efefc5fe8cf0d1")
