@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:52-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:24-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -54,51 +54,55 @@ rcseep_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
+  machine_word Wrd98;
+  machine_word Wrd97;
+  machine_word Wrd96;
+  machine_word Wrd95;
   machine_word Wrd93;
-  machine_word Wrd92;
-  machine_word Wrd91;
   machine_word Wrd90;
-  machine_word Wrd88;
+  machine_word Wrd76;
+  machine_word Wrd80;
+  machine_word Wrd78;
+  machine_word Wrd87;
+  machine_word Wrd86;
   machine_word Wrd85;
-  machine_word Wrd71;
-  machine_word Wrd75;
-  machine_word Wrd73;
+  machine_word Wrd84;
   machine_word Wrd82;
   machine_word Wrd81;
-  machine_word Wrd80;
-  machine_word Wrd79;
-  machine_word Wrd77;
-  machine_word Wrd76;
-  machine_word Wrd83;
-  machine_word Wrd70;
-  machine_word Wrd67;
-  machine_word Wrd58;
-  machine_word Wrd64;
+  machine_word Wrd88;
+  machine_word Wrd75;
+  machine_word Wrd72;
   machine_word Wrd63;
-  machine_word Wrd62;
-  machine_word Wrd65;
-  machine_word Wrd51;
-  machine_word Wrd52;
-  machine_word Wrd57;
+  machine_word Wrd69;
+  machine_word Wrd68;
+  machine_word Wrd67;
+  machine_word Wrd70;
   machine_word Wrd56;
-  machine_word Wrd53;
-  machine_word Wrd50;
+  machine_word Wrd57;
+  machine_word Wrd62;
+  machine_word Wrd61;
+  machine_word Wrd58;
+  machine_word Wrd55;
+  machine_word Wrd52;
+  machine_word Wrd38;
+  machine_word Wrd42;
+  machine_word Wrd40;
+  machine_word Wrd49;
+  machine_word Wrd48;
   machine_word Wrd47;
-  machine_word Wrd37;
+  machine_word Wrd46;
   machine_word Wrd44;
   machine_word Wrd43;
-  machine_word Wrd42;
-  machine_word Wrd41;
-  machine_word Wrd39;
-  machine_word Wrd38;
-  machine_word Wrd45;
-  machine_word Wrd32;
-  machine_word Wrd29;
-  machine_word Wrd20;
+  machine_word Wrd50;
+  machine_word Wrd37;
   machine_word Wrd25;
-  machine_word Wrd24;
+  machine_word Wrd29;
+  machine_word Wrd32;
   machine_word Wrd19;
+  machine_word Wrd24;
+  machine_word Wrd20;
+  machine_word Wrd104;
   machine_word Wrd11;
   machine_word Wrd10;
   machine_word Wrd12;
@@ -137,23 +141,23 @@ DEFLABEL (perform_dispatch)
     {
     case 0:
       current_block = (Rpc - LABEL_1_4);
-      goto expression_equivalentP_24;
+      goto expression_equivalentP_26;
 
     case 1:
       current_block = (Rpc - LABEL_1_7);
-      goto loop_37;
+      goto loop_39;
 
     case 2:
       current_block = (Rpc - LABEL_1_9);
-      goto label_26;
+      goto label_28;
 
     case 3:
       current_block = (Rpc - LABEL_1_10);
-      goto label_27;
+      goto label_29;
 
     case 4:
       current_block = (Rpc - LABEL_1_5);
-      goto register_equivalentP_23;
+      goto register_equivalentP_25;
 
     case 5:
       current_block = (Rpc - LABEL_1_15);
@@ -197,27 +201,27 @@ DEFLABEL (perform_dispatch)
 
     case 15:
       current_block = (Rpc - LABEL_1_28);
-      goto label_28;
+      goto label_30;
 
     case 16:
       current_block = (Rpc - LABEL_1_29);
-      goto label_29;
+      goto label_31;
 
     case 17:
       current_block = (Rpc - LABEL_1_30);
-      goto label_30;
+      goto label_32;
 
     case 18:
       current_block = (Rpc - LABEL_1_31);
-      goto label_31;
+      goto label_33;
 
     case 19:
       current_block = (Rpc - LABEL_1_32);
-      goto label_32;
+      goto label_34;
 
     case 20:
       current_block = (Rpc - LABEL_1_33);
-      goto label_33;
+      goto label_35;
 
     case 21:
       current_block = (Rpc - LABEL_1_27);
@@ -228,8 +232,8 @@ DEFLABEL (perform_dispatch)
       return (Rpc);
     }
 
-DEFLABEL (expression_equivalentP_35)
-DEFLABEL (expression_equivalentP_24)
+DEFLABEL (expression_equivalentP_37)
+DEFLABEL (expression_equivalentP_26)
   INTERRUPT_CHECK (26, LABEL_1_4);
   (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
   (Wrd17.pObj) = (Rhp + 1);
@@ -261,7 +265,7 @@ DEFLABEL (expression_equivalentP_24)
   Rsp = (& (Rsp [2]));
   goto loop_12;
 
-DEFLABEL (loop_37)
+DEFLABEL (loop_39)
   CLOSURE_HEADER (LABEL_1_7);
 
 DEFLABEL (loop_12)
@@ -269,38 +273,38 @@ DEFLABEL (loop_12)
   (Wrd8.Obj) = (Rsp [1]);
   (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
   if (! ((Wrd9.uLng) == 1))
-    goto label_49;
+    goto label_51;
   (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
   (Wrd7.Obj) = ((Wrd6.pObj) [0]);
   (* (--Rsp)) = (Wrd7.Obj);
 
-DEFLABEL (label_48)
+DEFLABEL (label_50)
   (Wrd17.Obj) = (Rsp [3]);
   (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
   if (! ((Wrd18.uLng) == 1))
-    goto label_47;
+    goto label_49;
   (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
   (Wrd14.Obj) = ((Wrd16.pObj) [0]);
 
-DEFLABEL (label_46)
+DEFLABEL (label_48)
   (Wrd23.Obj) = (Rsp [0]);
   if ((Wrd23.Obj) == (Wrd14.Obj))
-    goto label_38;
+    goto label_40;
   Rvl = ((SCHEME_OBJECT) 0);
   Rsp = (& (Rsp [4]));
   goto pop_return;
 
-DEFLABEL (label_38)
+DEFLABEL (label_40)
   if (! ((Wrd23.Obj) == (current_block [OBJECT_1_1])))
-    goto label_39;
+    goto label_41;
   (Wrd34.Obj) = (Rsp [1]);
   (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
   (Wrd33.Obj) = ((Wrd35.pObj) [2]);
   (Rsp [1]) = (Wrd33.Obj);
   Rsp = (& (Rsp [1]));
-  goto register_equivalentP_23;
+  goto register_equivalentP_25;
 
-DEFLABEL (label_39)
+DEFLABEL (label_41)
   (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_11]))));
   (* (--Rsp)) = (Wrd30.Obj);
   (Wrd31.Obj) = (current_block [OBJECT_1_2]);
@@ -311,9 +315,9 @@ DEFLABEL (label_39)
 DEFLABEL (continuation_4)
   INTERRUPT_CHECK (27, LABEL_1_11);
   if (! (Rvl == ((SCHEME_OBJECT) 0)))
-    goto label_41;
+    goto label_43;
 
-DEFLABEL (label_40)
+DEFLABEL (label_42)
   (Wrd15.Obj) = (Rsp [2]);
   (Wrd16.Obj) = (Rsp [3]);
   (Rsp [2]) = (Wrd16.Obj);
@@ -323,7 +327,7 @@ DEFLABEL (label_40)
   Rsp = (& (Rsp [1]));
   JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_18]));
 
-DEFLABEL (label_41)
+DEFLABEL (label_43)
   (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_15]))));
   (* (--Rsp)) = (Wrd9.Obj);
   (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_19]))));
@@ -342,7 +346,7 @@ DEFLABEL (continuation_5)
 DEFLABEL (continuation_6)
   INTERRUPT_CHECK (27, LABEL_1_15);
   if (Rvl == ((SCHEME_OBJECT) 0))
-    goto label_40;
+    goto label_42;
   (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_16]))));
   (* (--Rsp)) = (Wrd23.Obj);
   (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_17]))));
@@ -361,12 +365,12 @@ DEFLABEL (continuation_7)
 DEFLABEL (continuation_8)
   INTERRUPT_CHECK (27, LABEL_1_16);
   if (! (Rvl == ((SCHEME_OBJECT) 0)))
-    goto label_42;
+    goto label_44;
   Rvl = ((SCHEME_OBJECT) 0);
   Rsp = (& (Rsp [4]));
   goto pop_return;
 
-DEFLABEL (label_42)
+DEFLABEL (label_44)
   (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_24]))));
   (* (--Rsp)) = (Wrd9.Obj);
   (Wrd10.Obj) = (Rsp [4]);
@@ -386,40 +390,40 @@ DEFLABEL (continuation_9)
   INTERRUPT_CHECK (27, LABEL_1_27);
   (Wrd5.Obj) = (* (Rsp++));
   if (Rvl == (Wrd5.Obj))
-    goto label_44;
+    goto label_46;
   Rvl = ((SCHEME_OBJECT) 0);
-  goto label_43;
+  goto label_45;
 
-DEFLABEL (label_44)
+DEFLABEL (label_46)
   Rvl = (current_block [OBJECT_1_4]);
 
-DEFLABEL (label_43)
 DEFLABEL (label_45)
+DEFLABEL (label_47)
   Rsp = (& (Rsp [4]));
   goto pop_return;
 
-DEFLABEL (label_47)
+DEFLABEL (label_49)
   (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_10]))));
   (* (--Rsp)) = (Wrd22.Obj);
   (* (--Rsp)) = (Wrd17.Obj);
   INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 1);
 
-DEFLABEL (label_27)
+DEFLABEL (label_29)
   (Wrd14.Obj) = Rvl;
-  goto label_46;
+  goto label_48;
 
-DEFLABEL (label_49)
+DEFLABEL (label_51)
   (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_9]))));
   (* (--Rsp)) = (Wrd13.Obj);
   (* (--Rsp)) = (Wrd8.Obj);
   INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 1);
 
-DEFLABEL (label_26)
+DEFLABEL (label_28)
   (* (--Rsp)) = Rvl;
-  goto label_48;
+  goto label_50;
 
-DEFLABEL (register_equivalentP_36)
-DEFLABEL (register_equivalentP_23)
+DEFLABEL (register_equivalentP_38)
+DEFLABEL (register_equivalentP_25)
   INTERRUPT_CHECK (26, LABEL_1_5);
   (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_13]))));
   (* (--Rsp)) = (Wrd7.Obj);
@@ -462,189 +466,200 @@ DEFLABEL (continuation_15)
   INTERRUPT_CHECK (27, LABEL_1_26);
   (Wrd5.Obj) = (* (Rsp++));
   if (Rvl == (Wrd5.Obj))
-    goto label_51;
+    goto label_52;
   Rvl = ((SCHEME_OBJECT) 0);
-
-DEFLABEL (label_50)
   Rsp = (& (Rsp [5]));
   goto pop_return;
 
-DEFLABEL (label_51)
+DEFLABEL (label_52)
   (Wrd9.Obj) = (Rsp [2]);
   (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
   (Wrd11.Obj) = ((Wrd10.pObj) [2]);
   if ((Wrd11.Obj) == ((SCHEME_OBJECT) 0))
-    goto label_69;
-  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
-  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
-  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
-  if ((Wrd19.uLng) == 50)
-    goto label_68;
-  Wrd14 = Wrd18;
-
-DEFLABEL (label_67)
-  Wrd13 = Wrd14;
-  (Wrd27.uLng) = (OBJECT_TYPE (Wrd14.Obj));
-  if (! ((Wrd27.uLng) == 10))
-    goto label_66;
-  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
-  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
-  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
-  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd26.Lng))))
-    goto label_66;
-  (Wrd20.Obj) = ((Wrd24.pObj) [6]);
-
-DEFLABEL (label_65)
-  (Wrd45.uLng) = (OBJECT_TYPE (Wrd20.Obj));
-  if (! ((Wrd45.uLng) == 10))
-    goto label_64;
-  (Wrd38.Obj) = (Rsp [1]);
-  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
-  if (! ((Wrd39.uLng) == 26))
-    goto label_64;
-  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd38.Obj));
-  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
-  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
-  (Wrd44.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
-  if (! (((unsigned long) (Wrd41.Lng)) < ((unsigned long) (Wrd44.Lng))))
-    goto label_64;
-  (Wrd35.uLng) = (OBJECT_DATUM (Wrd38.Obj));
-  (Wrd37.pObj) = (& ((Wrd42.pObj) [(Wrd35.Lng)]));
-  (Wrd33.Obj) = ((Wrd37.pObj) [1]);
-
-DEFLABEL (label_63)
-  (Rsp [3]) = (Wrd33.Obj);
-  (Wrd53.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
-  (Wrd56.Obj) = ((Wrd53.pObj) [0]);
-  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
-  if ((Wrd57.uLng) == 50)
-    goto label_62;
-  Wrd52 = Wrd56;
-
-DEFLABEL (label_61)
-  Wrd51 = Wrd52;
-  (Wrd65.uLng) = (OBJECT_TYPE (Wrd52.Obj));
-  if (! ((Wrd65.uLng) == 10))
-    goto label_60;
-  (Wrd62.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
-  (Wrd63.Obj) = ((Wrd62.pObj) [0]);
-  (Wrd64.Lng) = (FIXNUM_TO_LONG (Wrd63.Obj));
-  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd64.Lng))))
-    goto label_60;
-  (Wrd58.Obj) = ((Wrd62.pObj) [5]);
-
-DEFLABEL (label_59)
-  (Wrd83.uLng) = (OBJECT_TYPE (Wrd58.Obj));
-  if (! ((Wrd83.uLng) == 10))
-    goto label_58;
-  (Wrd76.Obj) = (Rsp [1]);
-  (Wrd77.uLng) = (OBJECT_TYPE (Wrd76.Obj));
-  if (! ((Wrd77.uLng) == 26))
-    goto label_58;
-  (Wrd79.Lng) = (FIXNUM_TO_LONG (Wrd76.Obj));
-  (Wrd80.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
-  (Wrd81.Obj) = ((Wrd80.pObj) [0]);
-  (Wrd82.Lng) = (FIXNUM_TO_LONG (Wrd81.Obj));
-  if (! (((unsigned long) (Wrd79.Lng)) < ((unsigned long) (Wrd82.Lng))))
-    goto label_58;
-  (Wrd73.uLng) = (OBJECT_DATUM (Wrd76.Obj));
-  (Wrd75.pObj) = (& ((Wrd80.pObj) [(Wrd73.Lng)]));
-  (Wrd71.Obj) = ((Wrd75.pObj) [1]);
-
-DEFLABEL (label_57)
-  (Rsp [4]) = (Wrd71.Obj);
-  Rsp = (& (Rsp [3]));
-  (Wrd90.Obj) = (Rsp [0]);
-  (Wrd91.uLng) = (OBJECT_TYPE (Wrd90.Obj));
-  if ((Wrd91.uLng) == 26)
-    goto label_53;
-
-DEFLABEL (label_52)
-  INVOKE_INTERFACE_0 (36);
-
-DEFLABEL (label_53)
-  (Wrd92.Obj) = (Rsp [1]);
-  (Wrd93.uLng) = (OBJECT_TYPE (Wrd92.Obj));
-  if (! ((Wrd93.uLng) == 26))
-    goto label_52;
-  if ((Wrd90.Obj) == (Wrd92.Obj))
-    goto label_55;
-  Rvl = ((SCHEME_OBJECT) 0);
-  goto label_54;
-
-DEFLABEL (label_55)
-  Rvl = (current_block [OBJECT_1_4]);
+    goto label_54;
+  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
+  goto label_53;
 
 DEFLABEL (label_54)
+  (Wrd104.Obj) = (current_block [OBJECT_1_4]);
+  (* (--Rsp)) = (Wrd104.Obj);
+
+DEFLABEL (label_53)
+DEFLABEL (label_73)
+  (Wrd14.Obj) = (Rsp [0]);
+  if ((Wrd14.Obj) == ((SCHEME_OBJECT) 0))
+    goto label_55;
+  Rvl = (Wrd14.Obj);
+  Rsp = (& (Rsp [6]));
+  goto pop_return;
+
+DEFLABEL (label_55)
+  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
+  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
+  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
+  if ((Wrd24.uLng) == 50)
+    goto label_72;
+  Wrd19 = Wrd23;
+
+DEFLABEL (label_71)
+  Wrd18 = Wrd19;
+  (Wrd32.uLng) = (OBJECT_TYPE (Wrd19.Obj));
+  if (! ((Wrd32.uLng) == 10))
+    goto label_70;
+  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
+  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
+  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
+  if (! (((unsigned long) 5L) < ((unsigned long) (Wrd31.Lng))))
+    goto label_70;
+  (Wrd25.Obj) = ((Wrd29.pObj) [6]);
+
+DEFLABEL (label_69)
+  (Wrd50.uLng) = (OBJECT_TYPE (Wrd25.Obj));
+  if (! ((Wrd50.uLng) == 10))
+    goto label_68;
+  (Wrd43.Obj) = (Rsp [2]);
+  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
+  if (! ((Wrd44.uLng) == 26))
+    goto label_68;
+  (Wrd46.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
+  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
+  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
+  (Wrd49.Lng) = (FIXNUM_TO_LONG (Wrd48.Obj));
+  if (! (((unsigned long) (Wrd46.Lng)) < ((unsigned long) (Wrd49.Lng))))
+    goto label_68;
+  (Wrd40.uLng) = (OBJECT_DATUM (Wrd43.Obj));
+  (Wrd42.pObj) = (& ((Wrd47.pObj) [(Wrd40.Lng)]));
+  (Wrd38.Obj) = ((Wrd42.pObj) [1]);
+
+DEFLABEL (label_67)
+  (Rsp [4]) = (Wrd38.Obj);
+  (Wrd58.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
+  (Wrd61.Obj) = ((Wrd58.pObj) [0]);
+  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
+  if ((Wrd62.uLng) == 50)
+    goto label_66;
+  Wrd57 = Wrd61;
+
+DEFLABEL (label_65)
+  Wrd56 = Wrd57;
+  (Wrd70.uLng) = (OBJECT_TYPE (Wrd57.Obj));
+  if (! ((Wrd70.uLng) == 10))
+    goto label_64;
+  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
+  (Wrd68.Obj) = ((Wrd67.pObj) [0]);
+  (Wrd69.Lng) = (FIXNUM_TO_LONG (Wrd68.Obj));
+  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd69.Lng))))
+    goto label_64;
+  (Wrd63.Obj) = ((Wrd67.pObj) [5]);
+
+DEFLABEL (label_63)
+  (Wrd88.uLng) = (OBJECT_TYPE (Wrd63.Obj));
+  if (! ((Wrd88.uLng) == 10))
+    goto label_62;
+  (Wrd81.Obj) = (Rsp [2]);
+  (Wrd82.uLng) = (OBJECT_TYPE (Wrd81.Obj));
+  if (! ((Wrd82.uLng) == 26))
+    goto label_62;
+  (Wrd84.Lng) = (FIXNUM_TO_LONG (Wrd81.Obj));
+  (Wrd85.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
+  (Wrd86.Obj) = ((Wrd85.pObj) [0]);
+  (Wrd87.Lng) = (FIXNUM_TO_LONG (Wrd86.Obj));
+  if (! (((unsigned long) (Wrd84.Lng)) < ((unsigned long) (Wrd87.Lng))))
+    goto label_62;
+  (Wrd78.uLng) = (OBJECT_DATUM (Wrd81.Obj));
+  (Wrd80.pObj) = (& ((Wrd85.pObj) [(Wrd78.Lng)]));
+  (Wrd76.Obj) = ((Wrd80.pObj) [1]);
+
+DEFLABEL (label_61)
+  (Rsp [5]) = (Wrd76.Obj);
+  Rsp = (& (Rsp [4]));
+  (Wrd95.Obj) = (Rsp [0]);
+  (Wrd96.uLng) = (OBJECT_TYPE (Wrd95.Obj));
+  if ((Wrd96.uLng) == 26)
+    goto label_57;
+
 DEFLABEL (label_56)
+  INVOKE_INTERFACE_0 (36);
+
+DEFLABEL (label_57)
+  (Wrd97.Obj) = (Rsp [1]);
+  (Wrd98.uLng) = (OBJECT_TYPE (Wrd97.Obj));
+  if (! ((Wrd98.uLng) == 26))
+    goto label_56;
+  if ((Wrd95.Obj) == (Wrd97.Obj))
+    goto label_59;
+  Rvl = ((SCHEME_OBJECT) 0);
+  goto label_58;
+
+DEFLABEL (label_59)
+  Rvl = (current_block [OBJECT_1_4]);
+
+DEFLABEL (label_58)
+DEFLABEL (label_60)
   Rsp = (& (Rsp [2]));
   goto pop_return;
 
-DEFLABEL (label_58)
-  (Wrd85.Obj) = (Rsp [1]);
-  (Wrd88.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_33]))));
-  (* (--Rsp)) = (Wrd88.Obj);
-  (* (--Rsp)) = (Wrd85.Obj);
-  (* (--Rsp)) = (Wrd58.Obj);
-  INVOKE_PRIMITIVE ((current_block [OBJECT_1_6]), 2);
-
-DEFLABEL (label_33)
-  (Wrd71.Obj) = Rvl;
-  goto label_57;
-
-DEFLABEL (label_60)
-  (Wrd67.Obj) = (current_block [OBJECT_1_7]);
-  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_32]))));
-  (* (--Rsp)) = (Wrd70.Obj);
-  (* (--Rsp)) = (Wrd67.Obj);
-  (* (--Rsp)) = (Wrd51.Obj);
-  INVOKE_PRIMITIVE ((current_block [OBJECT_1_6]), 2);
-
-DEFLABEL (label_32)
-  (Wrd58.Obj) = Rvl;
-  goto label_59;
-
 DEFLABEL (label_62)
-  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_31])), (Wrd53.pObj));
+  (Wrd90.Obj) = (Rsp [2]);
+  (Wrd93.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_33]))));
+  (* (--Rsp)) = (Wrd93.Obj);
+  (* (--Rsp)) = (Wrd90.Obj);
+  (* (--Rsp)) = (Wrd63.Obj);
+  INVOKE_PRIMITIVE ((current_block [OBJECT_1_6]), 2);
 
-DEFLABEL (label_31)
-  (Wrd52.Obj) = Rvl;
+DEFLABEL (label_35)
+  (Wrd76.Obj) = Rvl;
   goto label_61;
 
 DEFLABEL (label_64)
-  (Wrd47.Obj) = (Rsp [1]);
-  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_30]))));
-  (* (--Rsp)) = (Wrd50.Obj);
-  (* (--Rsp)) = (Wrd47.Obj);
-  (* (--Rsp)) = (Wrd20.Obj);
+  (Wrd72.Obj) = (current_block [OBJECT_1_7]);
+  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_32]))));
+  (* (--Rsp)) = (Wrd75.Obj);
+  (* (--Rsp)) = (Wrd72.Obj);
+  (* (--Rsp)) = (Wrd56.Obj);
   INVOKE_PRIMITIVE ((current_block [OBJECT_1_6]), 2);
 
-DEFLABEL (label_30)
-  (Wrd33.Obj) = Rvl;
+DEFLABEL (label_34)
+  (Wrd63.Obj) = Rvl;
   goto label_63;
 
 DEFLABEL (label_66)
-  (Wrd29.Obj) = (current_block [OBJECT_1_5]);
-  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_29]))));
-  (* (--Rsp)) = (Wrd32.Obj);
-  (* (--Rsp)) = (Wrd29.Obj);
-  (* (--Rsp)) = (Wrd13.Obj);
-  INVOKE_PRIMITIVE ((current_block [OBJECT_1_6]), 2);
+  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_31])), (Wrd58.pObj));
 
-DEFLABEL (label_29)
-  (Wrd20.Obj) = Rvl;
+DEFLABEL (label_33)
+  (Wrd57.Obj) = Rvl;
   goto label_65;
 
 DEFLABEL (label_68)
-  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_28])), (Wrd15.pObj));
+  (Wrd52.Obj) = (Rsp [2]);
+  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_30]))));
+  (* (--Rsp)) = (Wrd55.Obj);
+  (* (--Rsp)) = (Wrd52.Obj);
+  (* (--Rsp)) = (Wrd25.Obj);
+  INVOKE_PRIMITIVE ((current_block [OBJECT_1_6]), 2);
 
-DEFLABEL (label_28)
-  (Wrd14.Obj) = Rvl;
+DEFLABEL (label_32)
+  (Wrd38.Obj) = Rvl;
   goto label_67;
 
-DEFLABEL (label_69)
-  Rvl = (current_block [OBJECT_1_4]);
-  goto label_50;
+DEFLABEL (label_70)
+  (Wrd34.Obj) = (current_block [OBJECT_1_5]);
+  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_29]))));
+  (* (--Rsp)) = (Wrd37.Obj);
+  (* (--Rsp)) = (Wrd34.Obj);
+  (* (--Rsp)) = (Wrd18.Obj);
+  INVOKE_PRIMITIVE ((current_block [OBJECT_1_6]), 2);
+
+DEFLABEL (label_31)
+  (Wrd25.Obj) = Rvl;
+  goto label_69;
+
+DEFLABEL (label_72)
+  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_28])), (Wrd20.pObj));
+
+DEFLABEL (label_30)
+  (Wrd19.Obj) = Rvl;
+  goto label_71;
 
 INVOKE_INTERFACE_TARGET_0
 INVOKE_PRIMITIVE_TARGET
@@ -673,7 +688,7 @@ rcseep_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd35;
   machine_word Wrd34;
   machine_word Wrd37;
@@ -848,7 +863,7 @@ rcseep_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd21;
   machine_word Wrd20;
   machine_word Wrd19;
@@ -956,7 +971,7 @@ rcseep_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd9;
   machine_word Wrd13;
   machine_word Wrd10;
@@ -1100,11 +1115,11 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-rcseep_so_8f7c838e42be1d36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+rcseep_so_4c1fded7df1c2cae (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd8;
   machine_word Wrd6;
   machine_word Wrd5;
@@ -1181,7 +1196,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_rcseep_so_8f7c838e42be1d36 [4] =
+static const struct liarc_code_S arr_decl_rcseep_so_4c1fded7df1c2cae [4] =
   {
     { "rcseep_so_code_1", 22, rcseep_so_code_1 },
     { "rcseep_so_code_2", 4, rcseep_so_code_2 },
@@ -1190,19 +1205,19 @@ static const struct liarc_code_S arr_decl_rcseep_so_8f7c838e42be1d36 [4] =
   };
 
 int
-decl_rcseep_so_8f7c838e42be1d36 (void)
+decl_rcseep_so_4c1fded7df1c2cae (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_rcseep_so_8f7c838e42be1d36);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_rcseep_so_4c1fded7df1c2cae);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("rcseep.so", 3, decl_rcseep_so_8f7c838e42be1d36, rcseep_so_8f7c838e42be1d36)
+DECLARE_COMPILED_CODE ("rcseep.so", 3, decl_rcseep_so_4c1fded7df1c2cae, rcseep_so_4c1fded7df1c2cae)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_rcseep_so_data_8f7c838e42be1d36 [921] =
+static const unsigned char prog_rcseep_so_data_4c1fded7df1c2cae [921] =
   "\x4a\x0b\xc8\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x84\xc2\x85\x07"
   "\x86\x0d\xb9\x0d\xba\x08\x89\x0d\xc1\xbb\x0d\x24\x28\x0d\xbc\x28"
   "\x0d\xbd\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22"
@@ -1217,9 +1232,9 @@ static const unsigned char prog_rcseep_so_data_8f7c838e42be1d36 [921] =
   "\x88\xb4\x1b\x2a\xb5\x2a\x1b\x2a\xb6\x2a\x9b\xb3\xb2\x0d\xb7\x9b"
   "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5b\x2f\x55\x73"
   "\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65"
-  "\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
-  "\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
-  "\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65"
+  "\x61\x73\x65\x2d\x39\x2e\x32\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65"
+  "\x6d\x65\x2d\x63\x2d\x39\x2e\x32\x2f\x73\x72\x63\x2f\x63\x6f\x6d"
   "\x70\x69\x6c\x65\x72\x2f\x72\x74\x6c\x6f\x70\x74\x2f\x72\x63\x73"
   "\x65\x65\x70\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69"
   "\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0b\x76\x65"
@@ -1235,8 +1250,8 @@ static const unsigned char prog_rcseep_so_data_8f7c838e42be1d36 [921] =
   "\x67\x69\x73\x74\x65\x72\x2d\x71\x75\x61\x6e\x74\x69\x74\x79\x03"
   "\x19\x73\x74\x61\x63\x6b\x2d\x72\x65\x66\x65\x72\x65\x6e\x63\x65"
   "\x2d\x71\x75\x61\x6e\x74\x69\x74\x79\x07\x19\x2e\x81\x8b\x02\x18"
-  "\x2c\x81\x8b\x02\x17\x2a\x81\x8b\x02\x16\x28\x81\x8b\x02\x15\x26"
-  "\x81\x8b\x02\x14\x24\x81\x8b\x02\x13\x22\x81\x8b\x02\x12\x20\x81"
+  "\x2c\x81\x8d\x02\x17\x2a\x81\x8d\x02\x16\x28\x81\x8d\x02\x15\x26"
+  "\x81\x8d\x02\x14\x24\x81\x8d\x02\x13\x22\x81\x8d\x02\x12\x20\x81"
   "\x8d\x02\x11\x1e\x81\x89\x02\x10\x1c\x81\x8b\x02\x0f\x1a\x81\x8b"
   "\x02\x0e\x18\x81\x89\x02\x0d\x16\x81\x89\x02\x0c\x14\x81\x8b\x02"
   "\x0b\x12\x81\x87\x02\x0a\x10\x81\x89\x02\x09\x0e\x81\x89\x02\x08"
@@ -1263,19 +1278,19 @@ static const unsigned char prog_rcseep_so_data_8f7c838e42be1d36 [921] =
   "\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-rcseep_so_data_8f7c838e42be1d36 (entry_count_t dispatch_base)
+rcseep_so_data_4c1fded7df1c2cae (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_rcseep_so_data_8f7c838e42be1d36 [0]))), (sizeof (prog_rcseep_so_data_8f7c838e42be1d36)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_rcseep_so_data_4c1fded7df1c2cae [0]))), (sizeof (prog_rcseep_so_data_4c1fded7df1c2cae)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("rcseep.so", rcseep_so_data_8f7c838e42be1d36)
+DECLARE_COMPILED_DATA_NS ("rcseep.so", rcseep_so_data_4c1fded7df1c2cae)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("rcseep.so", "e3269b8de97d6876")
+DECLARE_DYNAMIC_INITIALIZATION ("rcseep.so", "cf02f5ecb315fc00")
