@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:52-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:24-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -16,7 +16,7 @@ rcsesr_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   INVOKE_INTERFACE_DECLS
 
   Rdl = (OBJECT_ADDRESS (Rvl));
@@ -75,7 +75,7 @@ rcsesr_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd33;
   machine_word Wrd25;
   machine_word Wrd26;
@@ -332,7 +332,7 @@ rcsesr_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd33;
   machine_word Wrd25;
   machine_word Wrd26;
@@ -583,7 +583,7 @@ rcsesr_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd32;
   machine_word Wrd26;
   machine_word Wrd27;
@@ -734,7 +734,7 @@ rcsesr_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd30;
   machine_word Wrd29;
   machine_word Wrd15;
@@ -1017,7 +1017,7 @@ rcsesr_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd33;
   machine_word Wrd32;
   machine_word Wrd20;
@@ -1298,7 +1298,7 @@ rcsesr_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd69;
   machine_word Wrd68;
   machine_word Wrd65;
@@ -1549,7 +1549,7 @@ rcsesr_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd24;
   machine_word Wrd21;
   machine_word Wrd13;
@@ -1660,7 +1660,7 @@ rcsesr_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd26;
   machine_word Wrd25;
   machine_word Wrd18;
@@ -1774,7 +1774,7 @@ rcsesr_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd12;
   machine_word Wrd58;
   machine_word Wrd55;
@@ -2081,7 +2081,7 @@ rcsesr_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd23;
   machine_word Wrd5;
   machine_word Wrd27;
@@ -2335,11 +2335,11 @@ INVOKE_INTERFACE_TARGET_0
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-rcsesr_so_cf24852381b55d8c (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+rcsesr_so_23cfa064ea5fd92b (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd27;
   machine_word Wrd26;
   machine_word Wrd23;
@@ -2591,7 +2591,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_rcsesr_so_cf24852381b55d8c [11] =
+static const struct liarc_code_S arr_decl_rcsesr_so_23cfa064ea5fd92b [11] =
   {
     { "rcsesr_so_code_1", 1, rcsesr_so_code_1 },
     { "rcsesr_so_code_2", 8, rcsesr_so_code_2 },
@@ -2607,19 +2607,19 @@ static const struct liarc_code_S arr_decl_rcsesr_so_cf24852381b55d8c [11] =
   };
 
 int
-decl_rcsesr_so_cf24852381b55d8c (void)
+decl_rcsesr_so_23cfa064ea5fd92b (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_rcsesr_so_cf24852381b55d8c);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_rcsesr_so_23cfa064ea5fd92b);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("rcsesr.so", 12, decl_rcsesr_so_cf24852381b55d8c, rcsesr_so_cf24852381b55d8c)
+DECLARE_COMPILED_CODE ("rcsesr.so", 12, decl_rcsesr_so_23cfa064ea5fd92b, rcsesr_so_23cfa064ea5fd92b)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_rcsesr_so_data_cf24852381b55d8c [1699] =
+static const unsigned char prog_rcsesr_so_data_23cfa064ea5fd92b [1699] =
   "\x33\x12\xb5\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29\x21\x9c"
   "\x2b\xb9\x1d\xb0\x82\x88\x07\x87\xc1\xba\x0d\xc1\xbb\x28\x0d\xbc"
   "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
@@ -2648,10 +2648,10 @@ static const unsigned char prog_rcsesr_so_data_cf24852381b55d8c [1699] =
   "\x1e\x17\x28\x0d\x26\x0d\x0d\x0d\x24\x28\x0d\x28\x0d\x23\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5b\x2f\x55\x73\x65\x72\x73"
-  "\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63"
-  "\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c"
+  "\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x6d\x69"
+  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65"
+  "\x2d\x39\x2e\x32\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
+  "\x63\x2d\x39\x2e\x32\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c"
   "\x65\x72\x2f\x72\x74\x6c\x6f\x70\x74\x2f\x72\x63\x73\x65\x73\x72"
   "\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74"
   "\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0d\x04\x83\x04\x03\x02"
@@ -2729,19 +2729,19 @@ static const unsigned char prog_rcsesr_so_data_cf24852381b55d8c [1699] =
   "\x02\x19\x2f";
 
 SCHEME_OBJECT *
-rcsesr_so_data_cf24852381b55d8c (entry_count_t dispatch_base)
+rcsesr_so_data_23cfa064ea5fd92b (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_rcsesr_so_data_cf24852381b55d8c [0]))), (sizeof (prog_rcsesr_so_data_cf24852381b55d8c)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_rcsesr_so_data_23cfa064ea5fd92b [0]))), (sizeof (prog_rcsesr_so_data_23cfa064ea5fd92b)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_18]));
 }
 
-DECLARE_COMPILED_DATA_NS ("rcsesr.so", rcsesr_so_data_cf24852381b55d8c)
+DECLARE_COMPILED_DATA_NS ("rcsesr.so", rcsesr_so_data_23cfa064ea5fd92b)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("rcsesr.so", "b98eb9f8903e4026")
+DECLARE_DYNAMIC_INITIALIZATION ("rcsesr.so", "4b571e055ffc56de")
