@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-11-08T22:51:52-08 by Liar version 4.118. */
+/* generated 2014-05-17T03:05:24-07 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -79,7 +79,7 @@ rdebug_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd50;
   machine_word Wrd49;
   machine_word Wrd51;
@@ -1047,7 +1047,7 @@ rdebug_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd16;
   machine_word Wrd15;
   machine_word Wrd14;
@@ -1465,9 +1465,9 @@ DEFLABEL (continuation_9)
   (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
   (Wrd12.Obj) = ((Wrd11.pObj) [0]);
   (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
-  if (! (((unsigned long) 8L) < ((unsigned long) (Wrd13.Lng))))
+  if (! (((unsigned long) 10L) < ((unsigned long) (Wrd13.Lng))))
     goto label_62;
-  (Wrd7.Obj) = ((Wrd11.pObj) [9]);
+  (Wrd7.Obj) = ((Wrd11.pObj) [11]);
   (* (--Rsp)) = (Wrd7.Obj);
 
 DEFLABEL (label_61)
@@ -1598,11 +1598,11 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-rdebug_so_64002c58cfa55a4b (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+rdebug_so_700ec04494ad9c3e (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
-  SCHEME_OBJECT * Rdl;
+  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
   machine_word Wrd8;
   machine_word Wrd6;
   machine_word Wrd5;
@@ -1677,26 +1677,26 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_rdebug_so_64002c58cfa55a4b [2] =
+static const struct liarc_code_S arr_decl_rdebug_so_700ec04494ad9c3e [2] =
   {
     { "rdebug_so_code_1", 39, rdebug_so_code_1 },
     { "rdebug_so_code_2", 25, rdebug_so_code_2 }
   };
 
 int
-decl_rdebug_so_64002c58cfa55a4b (void)
+decl_rdebug_so_700ec04494ad9c3e (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_rdebug_so_64002c58cfa55a4b);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_rdebug_so_700ec04494ad9c3e);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("rdebug.so", 3, decl_rdebug_so_64002c58cfa55a4b, rdebug_so_64002c58cfa55a4b)
+DECLARE_COMPILED_CODE ("rdebug.so", 3, decl_rdebug_so_700ec04494ad9c3e, rdebug_so_700ec04494ad9c3e)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_rdebug_so_data_64002c58cfa55a4b [1187] =
+static const unsigned char prog_rdebug_so_data_700ec04494ad9c3e [1187] =
   "\x77\x09\xf6\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x0c\x0c\x0c"
   "\x0d\x85\x0c\x86\x0c\x0c\x83\x0c\xc2\xb9\x84\x1d\x0d\xba\x25\xb2"
   "\x24\x28\x0d\xbb\x28\x0d\x28\x0d\xbc\x28\x0d\xbd\x28\x0d\xbe\x28"
@@ -1713,10 +1713,10 @@ static const unsigned char prog_rdebug_so_data_64002c58cfa55a4b [1187] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
   "\x2b\xbe\x99\xbd\x88\xb5\xb6\x2a\xb7\x2a\x99\x0d\x0d\x99\x28\x0d"
   "\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5b\x2f\x55\x73\x65\x72"
-  "\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73"
-  "\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
-  "\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63"
-  "\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69"
+  "\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x6d"
+  "\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73"
+  "\x65\x2d\x39\x2e\x32\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
+  "\x2d\x63\x2d\x39\x2e\x32\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69"
   "\x6c\x65\x72\x2f\x72\x74\x6c\x6f\x70\x74\x2f\x72\x64\x65\x62\x75"
   "\x67\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61"
   "\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x10\x3b\x20\x63\x72"
@@ -1751,7 +1751,7 @@ static const unsigned char prog_rdebug_so_data_64002c58cfa55a4b [1187] =
   "\x73\x20\x6c\x69\x76\x65\x20\x61\x74\x20\x65\x6e\x64\x3a\x11\x62"
   "\x69\x74\x2d\x73\x74\x72\x69\x6e\x67\x2d\x7a\x65\x72\x6f\x3f\x11"
   "\x62\x69\x74\x2d\x73\x74\x72\x69\x6e\x67\x2d\x61\x6e\x64\x63\x21"
-  "\x09\x10\x62\x69\x74\x2d\x73\x74\x72\x69\x6e\x67\x2d\x73\x65\x74"
+  "\x0b\x10\x62\x69\x74\x2d\x73\x74\x72\x69\x6e\x67\x2d\x73\x65\x74"
   "\x21\x02\x10\x6d\x61\x6b\x65\x2d\x62\x69\x74\x2d\x73\x74\x72\x69"
   "\x6e\x67\x02\x02\x05\x03\x1a\x66\x6f\x72\x2d\x65\x61\x63\x68\x2d"
   "\x6d\x61\x63\x68\x69\x6e\x65\x2d\x72\x65\x67\x69\x73\x74\x65\x72"
@@ -1774,19 +1774,19 @@ static const unsigned char prog_rdebug_so_data_64002c58cfa55a4b [1187] =
   "\x02\x07\x11";
 
 SCHEME_OBJECT *
-rdebug_so_data_64002c58cfa55a4b (entry_count_t dispatch_base)
+rdebug_so_data_700ec04494ad9c3e (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_rdebug_so_data_64002c58cfa55a4b [0]))), (sizeof (prog_rdebug_so_data_64002c58cfa55a4b)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_rdebug_so_data_700ec04494ad9c3e [0]))), (sizeof (prog_rdebug_so_data_700ec04494ad9c3e)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("rdebug.so", rdebug_so_data_64002c58cfa55a4b)
+DECLARE_COMPILED_DATA_NS ("rdebug.so", rdebug_so_data_700ec04494ad9c3e)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("rdebug.so", "6182f8e98104cd11")
+DECLARE_DYNAMIC_INITIALIZATION ("rdebug.so", "fc7e5022385d254f")
